#include <TinyGPS++.h>
#include <TinyGPS.h>

#include <Adafruit_GFX.h>    // Core graphics library
#include <Adafruit_TFTLCD.h> // Hardware-specific library
#include <SoftwareSerial.h>

TinyGPSPlus tinyGPS;

#define LCD_CS A3
#define LCD_CD A2
#define LCD_WR A1
#define LCD_RD A0

#define LCD_RESET A4

#define GPS_BAUD 9600
#define ARDUINO_GPS_RX 10 // GPS TX, Arduino RX pin
#define ARDUINO_GPS_TX 11 // GPS RX, Arduino TX pin
#define gpsPort ssGPS

SoftwareSerial ssGPS(ARDUINO_GPS_TX, ARDUINO_GPS_RX); // Create a SoftwareSerial

#define BLACK   0x0000
#define BLUE    0x001F
#define RED     0xF800
#define GREEN   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define YELLOW  0xFFE0
#define WHITE   0xFFFF
#define ORANGE  0xF700

Adafruit_TFTLCD tft(LCD_CS, LCD_CD, LCD_WR, LCD_RD, LCD_RESET);

int shift=0;
int shift2=0;

long JD(int year, int month, int day)
{ // COMPUTES THE JULIAN DATE (JD) GIVEN A GREGORIAN CALENDAR
  return day-32075+1461L*(year+4800+(month-14)/12)/4+367*(month-2-(month-14)/12*12)/12-3*((year+4900+(month-14)/12)/100)/4;
}

long daysDiff(int year1, int mon1, int day1, int year2, int mon2, int day2)
{
  return JD(year2, mon2, day2) - JD(year1, mon1, day1);
}

long minutesDiff(int year1, int mon1, int day1, int hour1, int min1, int year2, int mon2, int day2, int hour2, int min2 )
{
  int mDiff= (hour2*60+min2) - (hour1*60+min1);
  return daysDiff(year1, mon1, day1, year2, mon2, day2)*1440 + mDiff;
}

int curMonth = tinyGPS.date.month();
int curYear = tinyGPS.date.year();
int curDay = tinyGPS.date.day();

long diffMinutes () {
int diffMinutes= daysDiff(2020, 1, 1, curYear, curMonth, curDay);
}

int myMap(float x, float in_min, float in_max, float out_min, long out_max) {
  return (x - in_min) * (out_max - out_min) / (in_max - in_min) + out_min;
}

void setup(void) {
  Serial.begin(9600);
  gpsPort.begin(GPS_BAUD);
  
  Serial.println(myMap(-80, -180, 180, -12,12));

  tft.reset();

  uint16_t identifier = tft.readID();

  tft.begin(identifier);

tft.fillScreen(BLACK);
  Serial.println(F("Done!"));
}

void drawCepheus() {
//Cepheus
tft.fillCircle(163, 115  + shift + 320, 2, GREEN);
tft.drawLine(163 , 115 + shift + 320, 52, 30 + shift + 320, GREEN);

tft.fillCircle(52 , 30 + shift + 320, 2, BLUE);
tft.drawLine(52 , 30 + shift + 320, 75 , 190 + shift + 320, BLUE);

tft.fillCircle(75 , 190 + shift + 320, 2, MAGENTA);
tft.drawLine(75 , 190 + shift + 320, 163 , 115 + shift + 320, MAGENTA);

tft.fillCircle(163 , 115 + shift + 320, 3, YELLOW);
tft.drawLine(163 , 115 + shift + 320, 205 , 210 + shift + 320, YELLOW);

tft.fillCircle(205 , 210 + shift + 320, 2, RED);
tft.drawLine(205 , 210 + shift + 320, 130 , 300 + shift + 320, RED);

tft.fillCircle(130 , 300 + shift + 320, 2, RED);
tft.drawLine(130 , 300 + shift + 320, 75 , 190 + shift + 320, RED);
}

void blankCepheus() {
// blank Cepheus
tft.fillCircle(163, 115  + shift + 320, 2, BLACK);
tft.drawLine(163 , 115 + shift + 320, 52, 30 + shift + 320, BLACK);

tft.fillCircle(52 , 30 + shift + 320, 2, BLACK);
tft.drawLine(52 , 30 + shift + 320, 75 , 190 + shift + 320, BLACK);

tft.fillCircle(75 , 190 + shift + 320, 2, BLACK);
tft.drawLine(75 , 190 + shift + 320, 163 , 115 + shift + 320, BLACK);

tft.fillCircle(163 , 115 + shift + 320, 3, BLACK);
tft.drawLine(163 , 115 + shift + 320, 205 , 210 + shift + 320, BLACK);

tft.fillCircle(205 , 210 + shift + 320, 2, BLACK);
tft.drawLine(205 , 210 + shift + 320, 130 , 300 + shift + 320, BLACK);

tft.fillCircle(130 , 300 + shift + 320, 2, BLACK);
tft.drawLine(130 , 300 + shift + 320, 75 , 190 + shift + 320, BLACK); 
}

void drawCassiopeia() {
//Cassiopeia
tft.fillCircle(160, 280 + shift + 640, 4, GREEN);
tft.drawLine(160, 280 + shift + 640, 52, 255 + shift + 640, GREEN);

tft.fillCircle(52, 255 + shift + 640, 4, BLUE);
tft.drawLine(52, 255 + shift + 640, 85, 178 + shift + 640, BLUE);

tft.fillCircle(85, 178 + shift + 640, 4, MAGENTA);
tft.drawLine(85, 178 + shift + 640, 28, 130 + shift + 640, MAGENTA);

tft.fillCircle(28, 130 + shift + 640, 3, YELLOW);
tft.drawLine(28, 130 + shift + 640, 60, 35 + shift + 640, YELLOW);
tft.fillCircle(60, 35 + shift + 640, 2, YELLOW);
}

void blankCassiopeia() {
//blank Cassiopeia
tft.fillCircle(160, 280 + shift + 640, 4, BLACK);
tft.drawLine(160, 280 + shift + 640, 52, 255 + shift + 640, BLACK);

tft.fillCircle(52, 255 + shift + 640, 4, BLACK);
tft.drawLine(52, 255 + shift + 640, 85, 178 + shift + 640, BLACK);

tft.fillCircle(85, 178 + shift + 640, 4, BLACK);
tft.drawLine(85, 178 + shift + 640, 28, 130 + shift + 640, BLACK);

tft.fillCircle(28, 130 + shift + 640, 3, BLACK);
tft.drawLine(28, 130 + shift + 640, 60, 35 + shift + 640, BLACK);
tft.fillCircle(60, 35 + shift + 640, 2, BLACK);
}

void drawCamelopardalis() {
//draw Camelopardalis
tft.fillCircle(37, 289 + shift + 960, 2, GREEN);
tft.drawLine(37, 289 + shift + 960, 52, 240 + shift + 960, GREEN);

tft.fillCircle(52, 240 + shift + 960, 1, BLUE);
tft.drawLine(52, 240 + shift + 960, 74, 140 + shift + 960, BLUE);
tft.fillCircle(74, 140 + shift + 960, 2, BLUE);

tft.fillCircle(139, 182 + shift + 960, 1, MAGENTA);
tft.drawLine(139, 182 + shift + 960, 74, 140 + shift + 960, MAGENTA);

tft.fillCircle(139, 182 + shift + 960, 2, YELLOW);
tft.drawLine(139, 182 + shift + 960, 190, 60 + shift + 960, YELLOW);

tft.fillCircle(139, 182 + shift + 960, 2, CYAN);
tft.drawLine(139, 182 + shift + 960, 37, 289 + shift + 960, CYAN);
}

void blankCamelopardalis() {
//blank Camelopardalis
tft.fillCircle(37, 289 + shift + 960, 2, BLACK);
tft.drawLine(37, 289 + shift + 960, 52, 240 + shift + 960, BLACK);

tft.fillCircle(52, 240 + shift + 960, 1, BLACK);
tft.drawLine(52, 240 + shift + 960, 74, 140 + shift + 960, BLACK);
tft.fillCircle(74, 140 + shift + 960, 2, BLACK);

tft.fillCircle(139, 182 + shift + 960, 1, BLACK);
tft.drawLine(139, 182 + shift + 960, 74, 140 + shift + 960, BLACK);

tft.fillCircle(139, 182 + shift + 960, 2, BLACK);
tft.drawLine(139, 182 + shift + 960, 190, 60 + shift + 960, BLACK);

tft.fillCircle(139, 182 + shift + 960, 2, BLACK);
tft.drawLine(139, 182 + shift + 960, 37, 289 + shift + 960, BLACK);
}

void drawLynx() {
// draw Lynx
tft.fillCircle(200, 20 + shift + 1280, 3, GREEN);
tft.drawLine(200, 20 + shift + 1280, 215, 60 + shift + 1280, GREEN);

tft.fillCircle(215, 60 + shift + 1280, 2, BLUE);
tft.drawLine(215, 60 + shift + 1280, 205, 95 + shift + 1280, BLUE);

tft.fillCircle(205, 95 + shift + 1280, 2, MAGENTA);
tft.drawLine(205, 95 + shift + 1280, 220, 115 + shift + 1280, MAGENTA);

tft.fillCircle(220, 115 + shift + 1280, 2, YELLOW);
tft.drawLine(220, 115 + shift + 1280, 190, 150 + shift + 1280, YELLOW);

tft.fillCircle(190, 150 + shift + 1280, 2, RED);
tft.drawLine(190, 150 + shift + 1280, 180, 200 + shift + 1280, RED);

tft.fillCircle(180, 200 + shift + 1280, 1, ORANGE);
tft.drawLine(180, 200 + shift + 1280, 197, 240 + shift + 1280, ORANGE);

tft.fillCircle(197, 240 + shift + 1280, 2, CYAN);
tft.drawLine(197, 240 + shift + 1280, 185, 270 + shift + 1280, CYAN);
tft.fillCircle(185, 270 + shift + 1280, 1, CYAN);
}

void blankLynx() {
// blank Lynx
tft.fillCircle(200, 20 + shift + 1280, 3, BLACK);
tft.drawLine(200, 20 + shift + 1280, 215, 60 + shift + 1280, BLACK);

tft.fillCircle(215, 60 + shift + 1280, 2, BLACK);
tft.drawLine(215, 60 + shift + 1280, 205, 95 + shift + 1280, BLACK);

tft.fillCircle(205, 95 + shift + 1280, 2, BLACK);
tft.drawLine(205, 95 + shift + 1280, 220, 115 + shift + 1280, BLACK);

tft.fillCircle(220, 115 + shift + 1280, 2, BLACK);
tft.drawLine(220, 115 + shift + 1280, 190, 150 + shift + 1280, BLACK);

tft.fillCircle(190, 150 + shift + 1280, 2, BLACK);
tft.drawLine(190, 150 + shift + 1280, 180, 200 + shift + 1280, BLACK);

tft.fillCircle(180, 200 + shift + 1280, 1, BLACK);
tft.drawLine(180, 200 + shift + 1280, 197, 240 + shift + 1280, BLACK);

tft.fillCircle(197, 240 + shift + 1280, 2, BLACK);
tft.drawLine(197, 240 + shift + 1280, 185, 270 + shift + 1280, BLACK);
tft.fillCircle(185, 270 + shift + 1280, 1, BLACK);
}

void drawUrsaMajor() {
//draw Ursa Major (Big Dipper)
tft.fillCircle(200, 17 + shift + 1600, 5, GREEN);
tft.drawLine(200, 17 + shift + 1600, 170, 45 + shift + 1600, GREEN);

tft.fillCircle(170, 45 + shift + 1600, 4, BLUE);
tft.drawLine(170, 45 + shift + 1600, 130, 50 + shift + 1600, BLUE);

tft.fillCircle(130, 50 + shift + 1600, 5, MAGENTA);
tft.drawLine(130, 50 + shift + 1600, 90, 60 + shift + 1600, MAGENTA);

tft.fillCircle(90, 60 + shift + 1600, 2, YELLOW);
tft.drawLine(90, 60 + shift + 1600, 57, 117 + shift + 1600, YELLOW);

tft.fillCircle(57, 117 + shift + 1600, 3, RED);
tft.drawLine(57, 117 + shift + 1600, 30, 82 + shift + 1600, RED);

tft.fillCircle(30, 82 + shift + 1600, 3, ORANGE);
tft.drawLine(30, 82 + shift + 1600, 55, 45 + shift + 1600, ORANGE);

tft.fillCircle(55, 45 + shift + 1600, 3, CYAN);
tft.drawLine(55, 45 + shift + 1600, 90, 60 + shift + 1600, CYAN); 
}

void blankUrsaMajor() {
//blank Ursa Major (Big Dipper)
tft.fillCircle(200, 17 + shift + 1600, 5, BLACK);
tft.drawLine(200, 17 + shift + 1600, 170, 45 + shift + 1600, BLACK);

tft.fillCircle(170, 45 + shift + 1600, 4, BLACK);
tft.drawLine(170, 45 + shift + 1600, 130, 50 + shift + 1600, BLACK);

tft.fillCircle(130, 50 + shift + 1600, 5, BLACK);
tft.drawLine(130, 50 + shift + 1600, 90, 60 + shift + 1600, BLACK);

tft.fillCircle(90, 60 + shift + 1600, 2, BLACK);
tft.drawLine(90, 60 + shift + 1600, 57, 117 + shift + 1600, BLACK);

tft.fillCircle(57, 117 + shift + 1600, 3, BLACK);
tft.drawLine(57, 117 + shift + 1600, 30, 82 + shift + 1600, BLACK);

tft.fillCircle(30, 82 + shift + 1600, 3, BLACK);
tft.drawLine(30, 82 + shift + 1600, 55, 45 + shift + 1600, BLACK);

tft.fillCircle(55, 45 + shift + 1600, 3, BLACK);
tft.drawLine(55, 45 + shift + 1600, 90, 60 + shift + 1600, BLACK);
}

void drawUrsaMinor() {
//Ursa Minor
tft.fillCircle(46, 74 + shift + shift2, 5, GREEN);
tft.drawLine(46, 74 + shift + shift2, 66, 81 + shift + shift2, GREEN);

tft.fillCircle(66, 81 + shift + shift2, 2, BLUE);
tft.drawLine(66, 81 + shift + shift2, 98, 86 + shift + shift2, BLUE);

tft.fillCircle(98, 86 + shift + shift2, 2, MAGENTA);
tft.drawLine(98, 86 + shift +  + shift2, 120, 79 + shift + shift2, MAGENTA);

tft.fillCircle(120, 79 + shift + shift2, 2, YELLOW);
tft.drawLine(120, 79 + shift + shift2, 135, 55 + shift + shift2, YELLOW);

tft.fillCircle(135, 55 + shift + shift2, 4, RED);
tft.drawLine(135, 55 + shift + shift2, 154, 67 + shift + shift2, RED);

tft.fillCircle(154, 67 + shift + shift2, 3, ORANGE);
tft.drawLine(154, 67 + shift + shift2, 134, 97 + shift + shift2, ORANGE);

tft.fillCircle(134, 97 + shift + shift2, 1, CYAN);
tft.drawLine(134, 97 + shift + shift2, 120, 79 + shift + shift2, CYAN);
}

void blankUrsaMinor() {
// blank Ursa Minor
tft.fillCircle(46, 74 + shift + shift2, 5, BLACK);
tft.drawLine(46, 74 + shift + shift2, 66, 81 + shift + shift2, BLACK);

tft.fillCircle(66, 81 + shift + shift2, 2, BLACK);
tft.drawLine(66, 81 + shift + shift2, 98, 86 + shift + shift2, BLACK);

tft.fillCircle(98, 86 + shift + shift2, 2, BLACK);
tft.drawLine(98, 86 + shift + shift2, 120, 79 + shift + shift2, BLACK);

tft.fillCircle(120, 79 + shift + shift2, 2, BLACK);
tft.drawLine(120, 79 + shift + shift2, 135, 55 + shift + shift2, BLACK);

tft.fillCircle(135, 55 + shift + shift2, 4, BLACK);
tft.drawLine(135, 55 + shift + shift2, 154, 67 + shift + shift2, BLACK);

tft.fillCircle(154, 67 + shift + shift2, 3, BLACK);
tft.drawLine(154, 67 + shift + shift2, 134, 97 + shift + shift2, BLACK);

tft.fillCircle(134, 97 + shift + shift2, 1, BLACK);
tft.drawLine(134, 97 + shift + shift2, 120, 79 + shift + shift2, BLACK); 
}

void drawDraco() {
//Draco
tft.fillCircle(46, 8 + shift + shift2, 1, GREEN);
tft.drawLine(46, 8 + shift + shift2, 86, 26 + shift + shift2, GREEN);

tft.fillCircle(86, 26 + shift + shift2, 2, BLUE);
tft.drawLine(86, 26 + shift + shift2, 148, 40 + shift + shift2, BLUE);

tft.fillCircle(148, 40 + shift + shift2, 2, MAGENTA);
tft.drawLine(148, 40 + shift + shift2, 225, 62 + shift + shift2, MAGENTA);

tft.fillCircle(225, 62 + shift + shift2, 2, YELLOW);
tft.drawLine(225, 62 + shift + shift2, 231, 94 + shift + shift2, YELLOW);

tft.fillCircle(231, 94 + shift + shift2, 2, RED);
tft.drawLine(231, 94 + shift + shift2, 202, 115 + shift + shift2, RED);

tft.fillCircle(202, 115 + shift + shift2, 3, ORANGE);
tft.drawLine(202, 115 + shift + shift2, 160, 138 + shift + shift2, ORANGE);

tft.fillCircle(160, 138 + shift + shift2, 2, CYAN);
tft.drawLine(160, 138 + shift + shift2, 89, 143 + shift + shift2, CYAN);

tft.fillCircle(89, 143 + shift + shift2, 2, GREEN);
tft.drawLine(89, 143 + shift + shift2, 55, 157 + shift + shift2, GREEN);

tft.fillCircle(55, 157 + shift + shift2, 2, BLUE);
tft.drawLine(55, 157 + shift + shift2, 47, 181 + shift + shift2, BLUE);

tft.fillCircle(47, 181 + shift + shift2, 2, MAGENTA);
tft.drawLine(47, 181 + shift + shift2, 79, 192 + shift + shift2, MAGENTA);

tft.fillCircle(79, 192 + shift + shift2, 3, YELLOW);
tft.drawLine(79, 192 + shift + shift2, 180, 200 + shift + shift2, YELLOW);

tft.fillCircle(180, 200 + shift + shift2, 2, RED);
tft.drawLine(180, 200 + shift + shift2, 210, 183 + shift + shift2, RED);

tft.fillCircle(210, 183 + shift + shift2, 1, ORANGE);
tft.drawLine(210, 183 + shift + shift2, 230, 193 + shift + shift2, ORANGE);

tft.fillCircle(230, 193 + shift + shift2, 3, CYAN);
tft.drawLine(230, 193 + shift + shift2, 219, 230 + shift + shift2, CYAN);

tft.fillCircle(219, 230 + shift + shift2, 4, CYAN);
tft.drawLine(219, 230 + shift + shift2, 180, 200 + shift + shift2, CYAN);
}

void blankDraco() {
// blank Draco
tft.fillCircle(46, 8 + shift + shift2, 1, BLACK);
tft.drawLine(46, 8 + shift + shift2, 86, 26 + shift + shift2, BLACK);

tft.fillCircle(86, 26 + shift + shift2, 2, BLACK);
tft.drawLine(86, 26 + shift + shift2, 148, 40 + shift + shift2, BLACK);

tft.fillCircle(148, 40 + shift + shift2, 2, BLACK);
tft.drawLine(148, 40 + shift + shift2, 225, 62 + shift + shift2, BLACK);

tft.fillCircle(225, 62 + shift + shift2, 2, BLACK);
tft.drawLine(225, 62 + shift + shift2, 231, 94 + shift + shift2, BLACK);

tft.fillCircle(231, 94 + shift + shift2, 2, BLACK);
tft.drawLine(231, 94 + shift + shift2, 202, 115 + shift + shift2, BLACK);

tft.fillCircle(202, 115 + shift + shift2, 3, BLACK);
tft.drawLine(202, 115 + shift + shift2, 160, 138 + shift + shift2, BLACK);

tft.fillCircle(160, 138 + shift + shift2, 2, BLACK);
tft.drawLine(160, 138 + shift + shift2, 89, 143 + shift + shift2, BLACK);

tft.fillCircle(89, 143 + shift + shift2, 2, BLACK);
tft.drawLine(89, 143 + shift + shift2, 55, 157 + shift + shift2, BLACK);

tft.fillCircle(55, 157 + shift + shift2, 2, BLACK);
tft.drawLine(55, 157 + shift + shift2, 47, 181 + shift + shift2, BLACK);

tft.fillCircle(47, 181 + shift + shift2, 2, BLACK);
tft.drawLine(47, 181 + shift + shift2, 79, 192 + shift + shift2, BLACK);

tft.fillCircle(79, 192 + shift + shift2, 3, BLACK);
tft.drawLine(79, 192 + shift + shift2, 180, 200 + shift + shift2, BLACK);

tft.fillCircle(180, 200 + shift + shift2, 2, BLACK);
tft.drawLine(180, 200 + shift + shift2, 210, 183 + shift + shift2, BLACK);

tft.fillCircle(210, 183 + shift + shift2, 1, BLACK);
tft.drawLine(210, 183 + shift + shift2, 230, 193 + shift + shift2, BLACK);

tft.fillCircle(230, 193 + shift + shift2, 3, BLACK);
tft.drawLine(230, 193 + shift + shift2, 219, 230 + shift + shift2, BLACK);

tft.fillCircle(219, 230 + shift + shift2, 4, BLACK);
tft.drawLine(219, 230 + shift + shift2, 180, 200 + shift + shift2, BLACK);
}

void loop(void) {

long minutesDiff = daysDiff(2020, 1, 1, curYear, curMonth, curDay);

int dayOffset = (minutesDiff * 4.78);
int hourOffset = tinyGPS.time.hour(); 
int utcOffset = myMap(tinyGPS.location.lng(), -180, 180, -12,12);

shift = (dayOffset + hourOffset + utcOffset);
 
  if(shift > -640 ){
  blankUrsaMinor();
  blankDraco();
  }
 
  if(shift > -960 && shift < 0)
  blankCepheus();

  if(shift > -1280 && shift < -320)
  blankCassiopeia();
 
   if(shift > -1600 && shift < -640)
  blankCamelopardalis();
 
    if(shift > -1920 && shift < -960)
  blankLynx();
 
   if(shift > -2240  && shift < -1280 )
  blankUrsaMajor();
 
   if(shift > -2560 ){
  blankUrsaMinor();
  blankDraco();
}
 
    if(shift < -1885 ){ //reset
  shift=0;
  shift2=0;
  }

Serial.println(shift); // debugging

// shift everything to new position to draw visible lines
  shift=-20;
     
   if(shift > -640){
  drawUrsaMinor();
  drawDraco();
   }
  if(shift >-960 && shift <0 )
  drawCepheus();

  if(shift > -1280 && shift < -320)
  drawCassiopeia();

  if(shift > -1600 && shift < -640)
  drawCamelopardalis();

  if(shift > -1920 && shift < -960)
  drawLynx();
 
  if(shift > -2240  && shift < -1280 ){
    drawUrsaMajor();
    shift2 = 1885; 
  }

    if(shift > -2560 && shift < -1600 ){
  drawUrsaMinor();
  drawDraco();
  }
   delay(1);  //we will change this delay to make it faster or slower depending on the GPS signal.

    // print position, altitude, speed, time/date, and satellites:
  printGPSInfo();

  // looks for GPS data while the Arduino's not doing anything else
  smartDelay(1000);
   
} //end loop

void printGPSInfo(void)
{
  Serial.print("Lat: "); Serial.println(tinyGPS.location.lat(), 6);
  Serial.print("Long: "); Serial.println(tinyGPS.location.lng(), 6);
  Serial.print("Alt: "); Serial.println(tinyGPS.altitude.feet());
  Serial.print("Course: "); Serial.println(tinyGPS.course.deg());
  Serial.print("Speed: "); Serial.println(tinyGPS.speed.mph());
  Serial.print("Date: "); printDate();
  Serial.print("Time: "); printTime();
  Serial.print("Sats: "); Serial.println(tinyGPS.satellites.value());
  Serial.println();
}
static void smartDelay(unsigned long ms)
{
  unsigned long start = millis();
  do
  {
    // If data has come in from the GPS module
    while (gpsPort.available())
      tinyGPS.encode(gpsPort.read()); // Send it to the encode function
  } while (millis() - start < ms);
}

// formats date into dd/mm/yy.
void printDate(void)
{
  Serial.print(tinyGPS.date.day());
  Serial.print("/");
  Serial.print(tinyGPS.date.month());
  Serial.print("/");
  Serial.println(tinyGPS.date.year());
  }
// formats time into "hh:mm:ss" and prints leading 0's where they're called for.
void printTime(void)
{
  Serial.print(tinyGPS.time.hour());
  Serial.print(":");
  if (tinyGPS.time.minute() < 10) Serial.print('0');
  Serial.print(tinyGPS.time.minute());
  Serial.print(":");
  if (tinyGPS.time.second() < 10) Serial.print('0');
  Serial.println(tinyGPS.time.second());
  }








 
