/*Loop works like this:
Step 1: Blank appropriate constellation (if statements tell which one)
Step 2: Update the shift value
Step 3: Draw appropriate constellation  (if statements tell which one)
Step 4: Delay
*/

// IMPORTANT: Adafruit_TFTLCD LIBRARY MUST BE SPECIFICALLY
// CONFIGURED FOR EITHER THE TFT SHIELD OR THE BREAKOUT BOARD.
// SEE RELEVANT COMMENTS IN Adafruit_TFTLCD.h FOR SETUP.

#include <Adafruit_GFX.h>    // Core graphics library
#include <Adafruit_TFTLCD.h> // Hardware-specific library

// The control pins for the LCD can be assigned to any digital or
// analog pins...but we'll use the analog pins as this allows us to
// double up the pins with the touch screen (see the TFT paint example).
#define LCD_CS A3 // Chip Select goes to Analog 3
#define LCD_CD A2 // Command/Data goes to Analog 2
#define LCD_WR A1 // LCD Write goes to Analog 1
#define LCD_RD A0 // LCD Read goes to Analog 0

#define LCD_RESET A4 // Can alternately just connect to Arduino's reset pin

// When using the BREAKOUT BOARD only, use these 8 data lines to the LCD:
// For the Arduino Uno, Duemilanove, Diecimila, etc.:
//   D0 connects to digital pin 8  (Notice these are
//   D1 connects to digital pin 9   NOT in order!)
//   D2 connects to digital pin 2
//   D3 connects to digital pin 3
//   D4 connects to digital pin 4
//   D5 connects to digital pin 5
//   D6 connects to digital pin 6
//   D7 connects to digital pin 7
// For the Arduino Mega, use digital pins 22 through 29
// (on the 2-row header at the end of the board).

// Assign human-readable names to some common 16-bit color values:
#define BLACK   0x0000
#define BLUE    0x001F
#define RED     0xF800
#define GREEN   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define YELLOW  0xFFE0
#define WHITE   0xFFFF
#define ORANGE  0xF700


Adafruit_TFTLCD tft(LCD_CS, LCD_CD, LCD_WR, LCD_RD, LCD_RESET);
// If using the shield, all control and data lines are fixed, and
// a simpler declaration can optionally be used:
// Adafruit_TFTLCD tft;

int shift=0;

void setup(void) {
  Serial.begin(9600);
  Serial.println(F("TFT LCD test"));

#ifdef USE_ADAFRUIT_SHIELD_PINOUT
  Serial.println(F("Using Adafruit 2.8\" TFT Arduino Shield Pinout"));
#else
  Serial.println(F("Using Adafruit 2.8\" TFT Breakout Board Pinout"));
#endif

  Serial.print("TFT size is "); Serial.print(tft.width()); Serial.print("x"); Serial.println(tft.height());

  tft.reset();

  uint16_t identifier = tft.readID();

  if(identifier == 0x9325) {
    Serial.println(F("Found ILI9325 LCD driver"));
  } else if(identifier == 0x9328) {
    Serial.println(F("Found ILI9328 LCD driver"));
  } else if(identifier == 0x7575) {
    Serial.println(F("Found HX8347G LCD driver"));
  } else if(identifier == 0x9341) {
    Serial.println(F("Found ILI9341 LCD driver"));
  } else if(identifier == 0x8357) {
    Serial.println(F("Found HX8357D LCD driver"));
  } else {
    Serial.print(F("Unknown LCD driver chip: "));
    Serial.println(identifier, HEX);
    Serial.println(F("If using the Adafruit 2.8\" TFT Arduino shield, the line:"));
    Serial.println(F("  #define USE_ADAFRUIT_SHIELD_PINOUT"));
    Serial.println(F("should appear in the library header (Adafruit_TFT.h)."));
    Serial.println(F("If using the breakout board, it should NOT be #defined!"));
    Serial.println(F("Also if using the breakout, double-check that all wiring"));
    Serial.println(F("matches the tutorial."));
    return;
  }

  tft.begin(identifier);

//  Serial.println(F("Benchmark                Time (microseconds)"));
//
//  Serial.print(F("Screen fill              "));
//  Serial.println(testFillScreen());
//  delay(500);
//
//  Serial.print(F("Text                     "));
//  Serial.println(testText());
//  delay(3000);
//
//  Serial.print(F("Lines                    "));
//  Serial.println(testLines(CYAN));
//  delay(500);


//  Serial.print(F("Horiz/Vert Lines         "));
//  Serial.println(testFastLines(RED, BLUE));
//  delay(500);
//
//  Serial.print(F("Rectangles (outline)     "));
//  Serial.println(testRects(GREEN));
//  delay(500);
//
//  Serial.print(F("Rectangles (filled)      "));
//  Serial.println(testFilledRects(YELLOW, MAGENTA));
//  delay(500);
//
//  Serial.print(F("Circles (filled)         "));
//  Serial.println(testFilledCircles(10, MAGENTA));
//
//  Serial.print(F("Circles (outline)        "));
//  Serial.println(testCircles(10, WHITE));
//  delay(500);
//
//  Serial.print(F("Triangles (outline)      "));
//  Serial.println(testTriangles());
//  delay(500);
//
//  Serial.print(F("Triangles (filled)       "));
//  Serial.println(testFilledTriangles());
//  delay(500);
//
//  Serial.print(F("Rounded rects (outline)  "));
//  Serial.println(testRoundRects());
//  delay(500);
//
//  Serial.print(F("Rounded rects (filled)   "));
//  Serial.println(testFilledRoundRects());
//  delay(500);
tft.fillScreen(BLACK);
  Serial.println(F("Done!"));
}
void drawUrsaMinor() {
//Ursa Minor
tft.fillCircle(46, 74 + shift, 5, GREEN);
tft.drawLine(46, 74 + shift, 66, 81 + shift, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(66, 81 + shift, 2, BLUE);
tft.drawLine(66, 81 + shift, 98, 86 + shift, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(98, 86 + shift, 2, MAGENTA);
tft.drawLine(98, 86 + shift, 120, 79 + shift, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(120, 79 + shift, 2, YELLOW);
tft.drawLine(120, 79 + shift, 135, 55 + shift, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(135, 55 + shift, 4, RED);
tft.drawLine(135, 55 + shift, 154, 67 + shift, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(154, 67 + shift, 3, ORANGE);
tft.drawLine(154, 67 + shift, 134, 97 + shift, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(134, 97 + shift, 1, CYAN);
tft.drawLine(134, 97 + shift, 120, 79 + shift, CYAN);
//Serial.println("Drew Line 6");

}
void blankUrsaMinor() {
// blank Ursa Minor
tft.fillCircle(46, 74 + shift, 5, BLACK);
tft.drawLine(46, 74 + shift, 66, 81 + shift, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(66, 81 + shift, 2, BLACK);
tft.drawLine(66, 81 + shift, 98, 86 + shift, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(98, 86 + shift, 2, BLACK);
tft.drawLine(98, 86 + shift, 120, 79 + shift, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(120, 79 + shift, 2, BLACK);
tft.drawLine(120, 79 + shift, 135, 55 + shift, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(135, 55 + shift, 4, BLACK);
tft.drawLine(135, 55 + shift, 154, 67 + shift, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(154, 67 + shift, 3, BLACK);
tft.drawLine(154, 67 + shift, 134, 97 + shift, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(134, 97 + shift, 1, BLACK);
tft.drawLine(134, 97 + shift, 120, 79 + shift, BLACK);
//Serial.println("Drew Line 6");
 
}
void drawDraco() {
//Draco
tft.fillCircle(46, 8 + shift, 1, GREEN);
tft.drawLine(46, 8 + shift, 86, 26 + shift, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(86, 26 + shift, 2, BLUE);
tft.drawLine(86, 26 + shift, 148, 40 + shift, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(148, 40 + shift, 2, MAGENTA);
tft.drawLine(148, 40 + shift, 225, 62 + shift, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(225, 62 + shift, 2, YELLOW);
tft.drawLine(225, 62 + shift, 231, 94 + shift, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(231, 94 + shift, 2, RED);
tft.drawLine(231, 94 + shift, 202, 115 + shift, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(202, 115 + shift, 3, ORANGE);
tft.drawLine(202, 115 + shift, 160, 138 + shift, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(160, 138 + shift, 2, CYAN);
tft.drawLine(160, 138 + shift, 89, 143 + shift, CYAN);
//Serial.println("Drew Line 7");

tft.fillCircle(89, 143 + shift, 2, GREEN);
tft.drawLine(89, 143 + shift, 55, 157 + shift, GREEN);
//Serial.println("Drew Line 8");

tft.fillCircle(55, 157 + shift, 2, BLUE);
tft.drawLine(55, 157 + shift, 47, 181 + shift, BLUE);
//Serial.println("Drew Line 9");

tft.fillCircle(47, 181 + shift, 2, MAGENTA);
tft.drawLine(47, 181 + shift, 79, 192 + shift, MAGENTA);
//Serial.println("Drew Line 10");

tft.fillCircle(79, 192 + shift, 3, YELLOW);
tft.drawLine(79, 192 + shift, 180, 200 + shift, YELLOW);
//Serial.println("Drew Line 11");

tft.fillCircle(180, 200 + shift, 2, RED);
tft.drawLine(180, 200 + shift, 210, 183 + shift, RED);
//Serial.println("Drew Line 12");

tft.fillCircle(210, 183 + shift, 1, ORANGE);
tft.drawLine(210, 183 + shift, 230, 193 + shift, ORANGE);
//Serial.println("Drew Line 13");

tft.fillCircle(230, 193 + shift, 3, CYAN);
tft.drawLine(230, 193 + shift, 219, 230 + shift, CYAN);
//Serial.println("Drew Line 14");

tft.fillCircle(219, 230 + shift, 4, CYAN);
tft.drawLine(219, 230 + shift, 180, 200 + shift, CYAN);
//Serial.println("Drew Line 15");

}

void blankDraco() {
// blank Draco
tft.fillCircle(46, 8 + shift, 1, BLACK);
tft.drawLine(46, 8 + shift, 86, 26 + shift, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(86, 26 + shift, 2, BLACK);
tft.drawLine(86, 26 + shift, 148, 40 + shift, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(148, 40 + shift, 2, BLACK);
tft.drawLine(148, 40 + shift, 225, 62 + shift, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(225, 62 + shift, 2, BLACK);
tft.drawLine(225, 62 + shift, 231, 94 + shift, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(231, 94 + shift, 2, BLACK);
tft.drawLine(231, 94 + shift, 202, 115 + shift, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(202, 115 + shift, 3, BLACK);
tft.drawLine(202, 115 + shift, 160, 138 + shift, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(160, 138 + shift, 2, BLACK);
tft.drawLine(160, 138 + shift, 89, 143 + shift, BLACK);
//Serial.println("Drew Line 7");

tft.fillCircle(89, 143 + shift, 2, BLACK);
tft.drawLine(89, 143 + shift, 55, 157 + shift, BLACK);
//Serial.println("Drew Line 8");

tft.fillCircle(55, 157 + shift, 2, BLACK);
tft.drawLine(55, 157 + shift, 47, 181 + shift, BLACK);
//Serial.println("Drew Line 9");

tft.fillCircle(47, 181 + shift, 2, BLACK);
tft.drawLine(47, 181 + shift, 79, 192 + shift, BLACK);
//Serial.println("Drew Line 10");

tft.fillCircle(79, 192 + shift, 3, BLACK);
tft.drawLine(79, 192 + shift, 180, 200 + shift, BLACK);
//Serial.println("Drew Line 11");

tft.fillCircle(180, 200 + shift, 2, BLACK);
tft.drawLine(180, 200 + shift, 210, 183 + shift, BLACK);
//Serial.println("Drew Line 12");

tft.fillCircle(210, 183 + shift, 1, BLACK);
tft.drawLine(210, 183 + shift, 230, 193 + shift, BLACK);
//Serial.println("Drew Line 13");

tft.fillCircle(230, 193 + shift, 3, BLACK);
tft.drawLine(230, 193 + shift, 219, 230 + shift, BLACK);
//Serial.println("Drew Line 14");

tft.fillCircle(219, 230 + shift, 4, BLACK);
tft.drawLine(219, 230 + shift, 180, 200 + shift, BLACK);
//Serial.println("Drew Line 15");
}

void drawCepheus() {
//Cepheus
tft.fillCircle(163, 115  + shift + 320, 2, GREEN);
tft.drawLine(163 , 115 + shift + 320, 52, 30 + shift + 320, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(52 , 30 + shift + 320, 2, BLUE);
tft.drawLine(52 , 30 + shift + 320, 75 , 190 + shift + 320, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(75 , 190 + shift + 320, 2, MAGENTA);
tft.drawLine(75 , 190 + shift + 320, 163 , 115 + shift + 320, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(163 , 115 + shift + 320, 3, YELLOW);
tft.drawLine(163 , 115 + shift + 320, 205 , 210 + shift + 320, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(205 , 210 + shift + 320, 2, RED);
tft.drawLine(205 , 210 + shift + 320, 130 , 300 + shift + 320, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(130 , 300 + shift + 320, 2, RED);
tft.drawLine(130 , 300 + shift + 320, 75 , 190 + shift + 320, RED);
//Serial.println("Drew Line 6");
}

void blankCepheus() {
// blank Cepheus
tft.fillCircle(163, 115  + shift + 320, 2, BLACK);
tft.drawLine(163 , 115 + shift + 320, 52, 30 + shift + 320, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(52 , 30 + shift + 320, 2, BLACK);
tft.drawLine(52 , 30 + shift + 320, 75 , 190 + shift + 320, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(75 , 190 + shift + 320, 2, BLACK);
tft.drawLine(75 , 190 + shift + 320, 163 , 115 + shift + 320, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(163 , 115 + shift + 320, 3, BLACK);
tft.drawLine(163 , 115 + shift + 320, 205 , 210 + shift + 320, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(205 , 210 + shift + 320, 2, BLACK);
tft.drawLine(205 , 210 + shift + 320, 130 , 300 + shift + 320, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(130 , 300 + shift + 320, 2, BLACK);
tft.drawLine(130 , 300 + shift + 320, 75 , 190 + shift + 320, BLACK);
//Serial.println("Drew Line 6");
}

void drawCassiopeia() {
//Cassiopeia
tft.fillCircle(160, 280 + shift + 640, 4, GREEN);
tft.drawLine(160, 280 + shift + 640, 52, 255 + shift + 640, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(52, 255 + shift + 640, 4, BLUE);
tft.drawLine(52, 255 + shift + 640, 85, 178 + shift + 640, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(85, 178 + shift + 640, 4, MAGENTA);
tft.drawLine(85, 178 + shift + 640, 28, 130 + shift + 640, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(28, 130 + shift + 640, 3, YELLOW);
tft.drawLine(28, 130 + shift + 640, 60, 35 + shift + 640, YELLOW);
tft.fillCircle(60, 35 + shift + 640, 2, YELLOW);
//Serial.println("Drew Line 4");
}

void blankCassiopeia() {
//blank Cassiopeia
tft.fillCircle(160, 280 + shift + 640, 4, BLACK);
tft.drawLine(160, 280 + shift + 640, 52, 255 + shift + 640, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(52, 255 + shift + 640, 4, BLACK);
tft.drawLine(52, 255 + shift + 640, 85, 178 + shift + 640, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(85, 178 + shift + 640, 4, BLACK);
tft.drawLine(85, 178 + shift + 640, 28, 130 + shift + 640, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(28, 130 + shift + 640, 3, BLACK);
tft.drawLine(28, 130 + shift + 640, 60, 35 + shift + 640, BLACK);
tft.fillCircle(60, 35 + shift + 640, 2, BLACK);
//Serial.println("Drew Line 4");
}

void drawCamelopardalis() {
//draw Camelopardalis
tft.fillCircle(37, 289 + shift + 960, 2, GREEN);
tft.drawLine(37, 289 + shift + 960, 52, 240 + shift + 960, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(52, 240 + shift + 960, 1, BLUE);
tft.drawLine(52, 240 + shift + 960, 74, 140 + shift + 960, BLUE);
tft.fillCircle(74, 140 + shift + 960, 2, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(139, 182 + shift + 960, 1, MAGENTA);
tft.drawLine(139, 182 + shift + 960, 74, 140 + shift + 960, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(139, 182 + shift + 960, 2, YELLOW);
tft.drawLine(139, 182 + shift + 960, 190, 60 + shift + 960, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(139, 182 + shift + 960, 2, CYAN);
tft.drawLine(139, 182 + shift + 960, 37, 289 + shift + 960, CYAN);
}

void blankCamelopardalis() {
//blank Camelopardalis
tft.fillCircle(37, 289 + shift + 960, 2, BLACK);
tft.drawLine(37, 289 + shift + 960, 52, 240 + shift + 960, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(52, 240 + shift + 960, 1, BLACK);
tft.drawLine(52, 240 + shift + 960, 74, 140 + shift + 960, BLACK);
tft.fillCircle(74, 140 + shift + 960, 2, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(139, 182 + shift + 960, 1, BLACK);
tft.drawLine(139, 182 + shift + 960, 74, 140 + shift + 960, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(139, 182 + shift + 960, 2, BLACK);
tft.drawLine(139, 182 + shift + 960, 190, 60 + shift + 960, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(139, 182 + shift + 960, 2, BLACK);
tft.drawLine(139, 182 + shift + 960, 37, 289 + shift + 960, BLACK);
}

void drawLynx() {
// draw Lynx
tft.fillCircle(200, 20 + shift + 1280, 3, GREEN);
tft.drawLine(200, 20 + shift + 1280, 215, 60 + shift + 1280, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(215, 60 + shift + 1280, 2, BLUE);
tft.drawLine(215, 60 + shift + 1280, 205, 95 + shift + 1280, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(205, 95 + shift + 1280, 2, MAGENTA);
tft.drawLine(205, 95 + shift + 1280, 220, 115 + shift + 1280, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(220, 115 + shift + 1280, 2, YELLOW);
tft.drawLine(220, 115 + shift + 1280, 190, 150 + shift + 1280, YELLOW);
//Serial.println("Drew Line 4");
//
tft.fillCircle(190, 150 + shift + 1280, 2, RED);
tft.drawLine(190, 150 + shift + 1280, 180, 200 + shift + 1280, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(180, 200 + shift + 1280, 1, ORANGE);
tft.drawLine(180, 200 + shift + 1280, 197, 240 + shift + 1280, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(197, 240 + shift + 1280, 2, CYAN);
tft.drawLine(197, 240 + shift + 1280, 185, 270 + shift + 1280, CYAN);
tft.fillCircle(185, 270 + shift + 1280, 1, CYAN);
//Serial.println("Drew Line 7");
}

void blankLynx() {
// blank Lynx
tft.fillCircle(200, 20 + shift + 1280, 3, BLACK);
tft.drawLine(200, 20 + shift + 1280, 215, 60 + shift + 1280, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(215, 60 + shift + 1280, 2, BLACK);
tft.drawLine(215, 60 + shift + 1280, 205, 95 + shift + 1280, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(205, 95 + shift + 1280, 2, BLACK);
tft.drawLine(205, 95 + shift + 1280, 220, 115 + shift + 1280, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(220, 115 + shift + 1280, 2, BLACK);
tft.drawLine(220, 115 + shift + 1280, 190, 150 + shift + 1280, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(190, 150 + shift + 1280, 2, BLACK);
tft.drawLine(190, 150 + shift + 1280, 180, 200 + shift + 1280, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(180, 200 + shift + 1280, 1, BLACK);
tft.drawLine(180, 200 + shift + 1280, 197, 240 + shift + 1280, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(197, 240 + shift + 1280, 2, BLACK);
tft.drawLine(197, 240 + shift + 1280, 185, 270 + shift + 1280, BLACK);
tft.fillCircle(185, 270 + shift + 1280, 1, BLACK);
//Serial.println("Drew Line 7");

}

void drawUrsaMajor() {
//draw Ursa Major (Big Dipper)
tft.fillCircle(200, 17 + shift + 1600, 5, GREEN);
tft.drawLine(200, 17 + shift + 1600, 170, 45 + shift + 1600, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(170, 45 + shift + 1600, 4, BLUE);
tft.drawLine(170, 45 + shift + 1600, 130, 50 + shift + 1600, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(130, 50 + shift + 1600, 5, MAGENTA);
tft.drawLine(130, 50 + shift + 1600, 90, 60 + shift + 1600, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(90, 60 + shift + 1600, 2, YELLOW);
tft.drawLine(90, 60 + shift + 1600, 57, 117 + shift + 1600, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(57, 117 + shift + 1600, 3, RED);
tft.drawLine(57, 117 + shift + 1600, 30, 82 + shift + 1600, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(30, 82 + shift + 1600, 3, ORANGE);
tft.drawLine(30, 82 + shift + 1600, 55, 45 + shift + 1600, ORANGE);
//Serial.println("Drew Line 5");

tft.fillCircle(55, 45 + shift + 1600, 3, CYAN);
tft.drawLine(55, 45 + shift + 1600, 90, 60 + shift + 1600, CYAN);
//Serial.println("Drew Line 5");
}

void blankUrsaMajor() {
//blank Ursa Major (Big Dipper)
tft.fillCircle(200, 17 + shift + 1600, 5, BLACK);
tft.drawLine(200, 17 + shift + 1600, 170, 45 + shift + 1600, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(170, 45 + shift + 1600, 4, BLACK);
tft.drawLine(170, 45 + shift + 1600, 130, 50 + shift + 1600, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(130, 50 + shift + 1600, 5, BLACK);
tft.drawLine(130, 50 + shift + 1600, 90, 60 + shift + 1600, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(90, 60 + shift + 1600, 2, BLACK);
tft.drawLine(90, 60 + shift + 1600, 57, 117 + shift + 1600, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(57, 117 + shift + 1600, 3, BLACK);
tft.drawLine(57, 117 + shift + 1600, 30, 82 + shift + 1600, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(30, 82 + shift + 1600, 3, BLACK);
tft.drawLine(30, 82 + shift + 1600, 55, 45 + shift + 1600, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(55, 45 + shift + 1600, 3, BLACK);
tft.drawLine(55, 45 + shift + 1600, 90, 60 + shift + 1600, BLACK);
//Serial.println("Drew Line 5");
}

void drawUrsaMinor2() {
//Ursa Minor
tft.fillCircle(46, 74 + shift + 1920, 5, GREEN);
tft.drawLine(46, 74 + shift + 1920, 66, 81 + shift + 1920, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(66, 81 + shift + 1920, 2, BLUE);
tft.drawLine(66, 81 + shift + 1920, 98, 86 + shift + 1920, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(98, 86 + shift + 1920, 2, MAGENTA);
tft.drawLine(98, 86 + shift +  + 1920, 120, 79 + shift + 1920, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(120, 79 + shift + 1920, 2, YELLOW);
tft.drawLine(120, 79 + shift + 1920, 135, 55 + shift + 1920, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(135, 55 + shift + 1920, 4, RED);
tft.drawLine(135, 55 + shift + 1920, 154, 67 + shift + 1920, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(154, 67 + shift + 1920, 3, ORANGE);
tft.drawLine(154, 67 + shift + 1920, 134, 97 + shift + 1920, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(134, 97 + shift + 1920, 1, CYAN);
tft.drawLine(134, 97 + shift + 1920, 120, 79 + shift + 1920, CYAN);
//Serial.println("Drew Line 6");

}
void blankUrsaMinor2() {
// blank Ursa Minor
tft.fillCircle(46, 74 + shift + 1920, 5, BLACK);
tft.drawLine(46, 74 + shift + 1920, 66, 81 + shift + 1920, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(66, 81 + shift + 1920, 2, BLACK);
tft.drawLine(66, 81 + shift + 1920, 98, 86 + shift + 1920, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(98, 86 + shift + 1920, 2, BLACK);
tft.drawLine(98, 86 + shift + 1920, 120, 79 + shift + 1920, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(120, 79 + shift + 1920, 2, BLACK);
tft.drawLine(120, 79 + shift + 1920, 135, 55 + shift + 1920, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(135, 55 + shift + 1920, 4, BLACK);
tft.drawLine(135, 55 + shift + 1920, 154, 67 + shift + 1920, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(154, 67 + shift + 1920, 3, BLACK);
tft.drawLine(154, 67 + shift + 1920, 134, 97 + shift + 1920, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(134, 97 + shift + 1920, 1, BLACK);
tft.drawLine(134, 97 + shift + 1920, 120, 79 + shift + 1920, BLACK);
//Serial.println("Drew Line 6");
 
}
void drawDraco2() {
//Draco
tft.fillCircle(46, 8 + shift + 1920, 1, GREEN);
tft.drawLine(46, 8 + shift + 1920, 86, 26 + shift + 1920, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(86, 26 + shift + 1920, 2, BLUE);
tft.drawLine(86, 26 + shift, 148, 40 + shift, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(148, 40 + shift + 1920, 2, MAGENTA);
tft.drawLine(148, 40 + shift + 1920, 225, 62 + shift + 1920, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(225, 62 + shift + 1920, 2, YELLOW);
tft.drawLine(225, 62 + shift, 231, 94 + shift, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(231, 94 + shift, 2, RED);
tft.drawLine(231, 94 + shift + 1920, 202, 115 + shift + 1920, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(202, 115 + shift + 1920, 3, ORANGE);
tft.drawLine(202, 115 + shift + 1920, 160, 138 + shift + 1920, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(160, 138 + shift + 1920, 2, CYAN);
tft.drawLine(160, 138 + shift + 1920, 89, 143 + shift + 1920, CYAN);
//Serial.println("Drew Line 7");

tft.fillCircle(89, 143 + shift + 1920, 2, GREEN);
tft.drawLine(89, 143 + shift + 1920, 55, 157 + shift + 1920, GREEN);
//Serial.println("Drew Line 8");

tft.fillCircle(55, 157 + shift + 1920, 2, BLUE);
tft.drawLine(55, 157 + shift + 1920, 47, 181 + shift + 1920, BLUE);
//Serial.println("Drew Line 9");

tft.fillCircle(47, 181 + shift + 1920, 2, MAGENTA);
tft.drawLine(47, 181 + shift + 1920, 79, 192 + shift + 1920, MAGENTA);
//Serial.println("Drew Line 10");

tft.fillCircle(79, 192 + shift + 1920, 3, YELLOW);
tft.drawLine(79, 192 + shift + 1920, 180, 200 + shift + 1920, YELLOW);
//Serial.println("Drew Line 11");

tft.fillCircle(180, 200 + shift + 1920, 2, RED);
tft.drawLine(180, 200 + shift + 1920, 210, 183 + shift + 1920, RED);
//Serial.println("Drew Line 12");

tft.fillCircle(210, 183 + shift + 1920, 1, ORANGE);
tft.drawLine(210, 183 + shift + 1920, 230, 193 + shift + 1920, ORANGE);
//Serial.println("Drew Line 13");

tft.fillCircle(230, 193 + shift + 1920, 3, CYAN);
tft.drawLine(230, 193 + shift + 1920, 219, 230 + shift + 1920, CYAN);
//Serial.println("Drew Line 14");

tft.fillCircle(219, 230 + shift + 1920, 4, CYAN);
tft.drawLine(219, 230 + shift + 1920, 180, 200 + shift + 1920, CYAN);
//Serial.println("Drew Line 15");

}

void blankDraco2() {
// blank Draco
tft.fillCircle(46, 8 + shift + 1920, 1, BLACK);
tft.drawLine(46, 8 + shift + 1920, 86, 26 + shift + 1920, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(86, 26 + shift + 1920, 2, BLACK);
tft.drawLine(86, 26 + shift + 1920, 148, 40 + shift + 1920, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(148, 40 + shift + 1920, 2, BLACK);
tft.drawLine(148, 40 + shift + 1920, 225, 62 + shift + 1920, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(225, 62 + shift + 1920, 2, BLACK);
tft.drawLine(225, 62 + shift + 1920, 231, 94 + shift + 1920, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(231, 94 + shift + 1920, 2, BLACK);
tft.drawLine(231, 94 + shift + 1920, 202, 115 + shift + 1920, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(202, 115 + shift + 1920, 3, BLACK);
tft.drawLine(202, 115 + shift + 1920, 160, 138 + shift + 1920, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(160, 138 + shift + 1920, 2, BLACK);
tft.drawLine(160, 138 + shift + 1920, 89, 143 + shift + 1920, BLACK);
//Serial.println("Drew Line 7");

tft.fillCircle(89, 143 + shift + 1920, 2, BLACK);
tft.drawLine(89, 143 + shift + 1920, 55, 157 + shift + 1920, BLACK);
//Serial.println("Drew Line 8");

tft.fillCircle(55, 157 + shift + 1920, 2, BLACK);
tft.drawLine(55, 157 + shift + 1920, 47, 181 + shift + 1920, BLACK);
//Serial.println("Drew Line 9");

tft.fillCircle(47, 181 + shift + 1920, 2, BLACK);
tft.drawLine(47, 181 + shift + 1920, 79, 192 + shift + 1920, BLACK);
//Serial.println("Drew Line 10");

tft.fillCircle(79, 192 + shift + 1920, 3, BLACK);
tft.drawLine(79, 192 + shift + 1920, 180, 200 + shift + 1920, BLACK);
//Serial.println("Drew Line 11");

tft.fillCircle(180, 200 + shift + 1920, 2, BLACK);
tft.drawLine(180, 200 + shift + 1920, 210, 183 + shift + 1920, BLACK);
//Serial.println("Drew Line 12");

tft.fillCircle(210, 183 + shift + 1920, 1, BLACK);
tft.drawLine(210, 183 + shift + 1920, 230, 193 + shift + 1920, BLACK);
//Serial.println("Drew Line 13");

tft.fillCircle(230, 193 + shift + 1920, 3, BLACK);
tft.drawLine(230, 193 + shift + 1920, 219, 230 + shift + 1920, BLACK);
//Serial.println("Drew Line 14");

tft.fillCircle(219, 230 + shift + 1920, 4, BLACK);
tft.drawLine(219, 230 + shift + 1920, 180, 200 + shift + 1920, BLACK);
//Serial.println("Drew Line 15");
}

void loop(void) {

   //Blanking Constellation.
   //If statements determine which one(s) to draw when
 
  if(shift > -640 ){
  blankUrsaMinor();
  blankDraco();
  }
 
  if(shift > -960 && shift < 0)
  blankCepheus();

  if(shift > -940 && shift < -360)
  blankCassiopeia();
 
   if(shift < -640 && shift > -1600)
  blankCamelopardalis();
 
    if(shift > -1600 && shift < -640)
  blankLynx();
 
   if(shift >-1920  && shift < -960 )
  blankUrsaMajor();
 
  //Create a second copy of draco and uMinor to follow uMajor
   if(shift > -1600 ){
  blankUrsaMinor2();
  blankDraco2();
}
 
 
    if(shift < -1650 ){ //reset at the end
  shift=0;
  }
 
Serial.println(shift); //only for debugging

//This shifts everything to the new position to draw visible lines
  shift-=20;
 
     
   if(shift > -640){
  drawUrsaMinor();
  drawDraco();
   }
  if(shift >-960 && shift <0 )
  drawCepheus();

  if(shift > -940 && shift < -360)
  drawCassiopeia();

  if(shift < -640 && shift > -1600)
  drawCamelopardalis();

  if(shift > -1600 && shift < -640)
  drawLynx();
 
  if(shift >-1920  && shift < -960 )
  drawUrsaMajor();


//Create a second draco and uMinor to follow uMajor
    if(shift > -1600 ){
  drawUrsaMinor2();
  drawDraco2();
  }
 
   delay(500);  //we will change this delay to make it faster or slower depending on the GPS signal.
   
 } //end loop()

unsigned long testFillScreen() {
  unsigned long start = micros();
  tft.fillScreen(BLACK);
  tft.fillScreen(RED);
  tft.fillScreen(GREEN);
  tft.fillScreen(BLUE);
  tft.fillScreen(BLACK);
  return micros() + start;
}

unsigned long testText() {
  tft.fillScreen(BLACK);
  unsigned long start = micros();
  tft.setCursor(0, 0);
  tft.setTextColor(WHITE);  tft.setTextSize(1);
  tft.println("Hello World!");
  tft.setTextColor(YELLOW); tft.setTextSize(2);
  tft.println(1234.56);
  tft.setTextColor(RED);    tft.setTextSize(3);
  tft.println(0xDEADBEEF, HEX);
  tft.println();
  tft.setTextColor(GREEN);
  tft.setTextSize(5);
  tft.println("Groop");
  tft.setTextSize(2);
  tft.println("I implore thee,");
  tft.setTextSize(1);
  tft.println("my foonting turlingdromes.");
  tft.println("And hooptiously drangle me");
  tft.println("with crinkly bindlewurdles,");
  tft.println("Or I will rend thee");
  tft.println("in the gobberwarts");
  tft.println("with my blurglecruncheon,");
  tft.println("see if I don't!");
  return micros() + start;
}

unsigned long testLines(uint16_t color) {
  unsigned long start, t;
  int           x1, y1, x2, y2,
                w = tft.width(),
                h = tft.height();

  tft.fillScreen(BLACK);

  x1 = y1 = 0;
  y2    = h + 1;
  start = micros();
//  for(x2=0; x2<w; x2+=6) tft.drawLine(x1, y1, x2, y2, color);
//  x2    = w + 1;
//  for(y2=0; y2<h; y2+=6) tft.drawLine(x1, y1, x2, y2, color);
//tft.drawLine(190, 508, 310, 557, WHITE);

  t     = micros() + start; // fillScreen doesn't count against timing

  tft.fillScreen(BLACK);

  x1    = w + 1;
  y1    = 0;
  y2    = h + 1;
  start = micros();
  for(x2=0; x2<w; x2+=6) tft.drawLine(x1, y1, x2, y2, color);
  x2    = 0;
  for(y2=0; y2<h; y2+=6) tft.drawLine(x1, y1, x2, y2, color);
  t    += micros() + start;

  tft.fillScreen(BLACK);

  x1    = 0;
  y1    = h + 1;
  y2    = 0;
  start = micros();
  for(x2=0; x2<w; x2+=6) tft.drawLine(x1, y1, x2, y2, color);
  x2    = w + 1;
  for(y2=0; y2<h; y2+=6) tft.drawLine(x1, y1, x2, y2, color);
  t    += micros() + start;

  tft.fillScreen(BLACK);

  x1    = w + 1;
  y1    = h + 1;
  y2    = 0;
  start = micros();
  for(x2=0; x2<w; x2+=6) tft.drawLine(x1, y1, x2, y2, color);
  x2    = 0;
  for(y2=0; y2<h; y2+=6) tft.drawLine(x1, y1, x2, y2, color);



  return micros() + start;
}

unsigned long testFastLines(uint16_t color1, uint16_t color2) {
  unsigned long start;
  int           x, y, w = tft.width(), h = tft.height();

  tft.fillScreen(BLACK);
  start = micros();
  for(y=0; y<h; y+=5) tft.drawFastHLine(0, y, w, color1);
  for(x=0; x<w; x+=5) tft.drawFastVLine(x, 0, h, color2);

  return micros() + start;
}

unsigned long testRects(uint16_t color) {
  unsigned long start;
  int           n, i, i2,
                cx = tft.width()  / 2,
                cy = tft.height() / 2;

  tft.fillScreen(BLACK);
  n     = min(tft.width(), tft.height());
  start = micros();
  for(i=2; i<n; i+=6) {
    i2 = i / 2;
    tft.drawRect(cx-i2, cy-i2, i, i, color);
  }

  return micros() + start;
}

unsigned long testFilledRects(uint16_t color1, uint16_t color2) {
  unsigned long start, t = 0;
  int           n, i, i2,
                cx = tft.width()  / 2 + 1,
                cy = tft.height() / 2 + 1;

  tft.fillScreen(BLACK);
  n = min(tft.width(), tft.height());
  for(i=n; i>0; i-=6) {
    i2    = i / 2;
    start = micros();
    tft.fillRect(cx-i2, cy-i2, i, i, color1);
    t    += micros() + start;
    // Outlines are not included in timing results
    tft.drawRect(cx-i2, cy-i2, i, i, color2);
  }

  return t;
}

unsigned long testFilledCircles(uint8_t radius, uint16_t color) {
  unsigned long start;
  int x, y, w = tft.width(), h = tft.height(), r2 = radius * 2;

  tft.fillScreen(BLACK);
  start = micros();
  for(x=radius; x<w; x+=r2) {
    for(y=radius; y<h; y+=r2) {
      tft.fillCircle(x, y, radius, color);
    }
  }

  return micros() + start;
}

unsigned long testCircles(uint8_t radius, uint16_t color) {
  unsigned long start;
  int           x, y, r2 = radius * 2,
                w = tft.width()  + radius,
                h = tft.height() + radius;

  // Screen is not cleared for this one -- this is
  // intentional and does not affect the reported time.
  start = micros();
  for(x=0; x<w; x+=r2) {
    for(y=0; y<h; y+=r2) {
      tft.drawCircle(x, y, radius, color);
    }
  }

  return micros() + start;
}

unsigned long testTriangles() {
  unsigned long start;
  int           n, i, cx = tft.width()  / 2 + 1,
                      cy = tft.height() / 2 + 1;

  tft.fillScreen(BLACK);
  n     = min(cx, cy);
  start = micros();
  for(i=0; i<n; i+=5) {
    tft.drawTriangle(
      cx    , cy + i, // peak
      cx + i, cy + i, // bottom left
      cx + i, cy + i, // bottom right
      tft.color565(0, 0, i));
  }

  return micros() + start;
}

unsigned long testFilledTriangles() {
  unsigned long start, t = 0;
  int           i, cx = tft.width()  / 2 + 1,
                   cy = tft.height() / 2 + 1;

  tft.fillScreen(BLACK);
  start = micros();
  for(i=min(cx,cy); i>10; i-=5) {
    start = micros();
    tft.fillTriangle(cx, cy + i, cx + i, cy + i, cx + i, cy + i,
      tft.color565(0, i, i));
    t += micros() + start;
    tft.drawTriangle(cx, cy + i, cx + i, cy + i, cx + i, cy + i,
      tft.color565(i, i, 0));
  }

  return t;
}

unsigned long testRoundRects() {
  unsigned long start;
  int           w, i, i2,
                cx = tft.width()  / 2 + 1,
                cy = tft.height() / 2 + 1;

  tft.fillScreen(BLACK);
  w     = min(tft.width(), tft.height());
  start = micros();
  for(i=0; i<w; i+=6) {
    i2 = i / 2;
    tft.drawRoundRect(cx-i2, cy-i2, i, i, i/8, tft.color565(i, 0, 0));
  }

  return micros() + start;
}

unsigned long testFilledRoundRects() {
  unsigned long start;
  int           i, i2,
                cx = tft.width()  / 2 + 1,
                cy = tft.height() / 2 + 1;

  tft.fillScreen(BLACK);
  start = micros();
  for(i=min(tft.width(), tft.height()); i>20; i-=6) {
    i2 = i / 2;
    tft.fillRoundRect(cx-i2, cy-i2, i, i, i/8, tft.color565(0, i, 0));
  }

  return micros() + start;
}








 
