#include <TinyGPS++.h>
#include <TinyGPS.h>

#include <Adafruit_GFX.h>    // Core graphics library
#include <Adafruit_TFTLCD.h> // Hardware-specific library
#include <SoftwareSerial.h>

TinyGPSPlus tinyGPS; // Create a TinyGPSPlus object

#define LCD_CS A3 // Chip Select goes to Analog 3
#define LCD_CD A2 // Command/Data goes to Analog 2
#define LCD_WR A1 // LCD Write goes to Analog 1
#define LCD_RD A0 // LCD Read goes to Analog 0

#define LCD_RESET A4 // Can alternately just connect to Arduino's reset pin

#define GPS_BAUD 9600
#define ARDUINO_GPS_RX 10 // GPS TX, Arduino RX pin
#define ARDUINO_GPS_TX 11 // GPS RX, Arduino TX pin
#define gpsPort ssGPS  // Alternatively, use Serial1 on the Leonardo

SoftwareSerial ssGPS(ARDUINO_GPS_TX, ARDUINO_GPS_RX); // Create a SoftwareSerial

#define BLACK   0x0000
#define BLUE    0x001F
#define RED     0xF800
#define GREEN   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define YELLOW  0xFFE0
#define WHITE   0xFFFF
#define ORANGE  0xF700

Adafruit_TFTLCD tft(LCD_CS, LCD_CD, LCD_WR, LCD_RD, LCD_RESET);

int shift=0;

long JD(int year, int month, int day)
{ // COMPUTES THE JULIAN DATE (JD) GIVEN A GREGORIAN CALENDAR
  return day-32075+1461L*(year+4800+(month-14)/12)/4+367*(month-2-(month-14)/12*12)/12-3*((year+4900+(month-14)/12)/100)/4;
}

long daysDiff(int year1, int mon1, int day1, int year2, int mon2, int day2)
{
  return JD(year2, mon2, day2) - JD(year1, mon1, day1);
}

long minutesDiff(int year1, int mon1, int day1, int hour1, int min1, int year2, int mon2, int day2, int hour2, int min2 )
{
  int mDiff= (hour2*60+min2) - (hour1*60+min1);
  return daysDiff(year1, mon1, day1, year2, mon2, day2)*1440 + mDiff;
}

int curMonth = tinyGPS.date.month();
int curYear = tinyGPS.date.year();
int curDay = tinyGPS.date.day();

long diffMinutes () {
int diffMinutes= daysDiff(2020, 1, 1, curYear, curMonth, curDay);
}
  
//long map(long 0, long -80, long 80, long -12, long 12) 
//{
//  return (0 - -80) * (12 - -12) / (80 - -80) + -12;
//}

void setup(void) {
  Serial.begin(9600);
  gpsPort.begin(GPS_BAUD);
  Serial.println(F("TFT LCD test"));
  
  Serial.print("TFT size is "); Serial.print(tft.width()); Serial.print("x"); Serial.println(tft.height());

  tft.reset();

  uint16_t identifier = tft.readID();
//
//  if(identifier == 0x9325) {
//    Serial.println(F("Found ILI9325 LCD driver"));
//  } else if(identifier == 0x9328) {
//    Serial.println(F("Found ILI9328 LCD driver"));
//  } else if(identifier == 0x7575) {
//    Serial.println(F("Found HX8347G LCD driver"));
//  } else if(identifier == 0x9341) {
//    Serial.println(F("Found ILI9341 LCD driver"));
//  } else if(identifier == 0x8357) {
//    Serial.println(F("Found HX8357D LCD driver"));
//  } else {
//    Serial.print(F("Unknown LCD driver chip: "));
//    Serial.println(identifier, HEX);
//    Serial.println(F("If using the Adafruit 2.8\" TFT Arduino shield, the line:"));
//    Serial.println(F("  #define USE_ADAFRUIT_SHIELD_PINOUT"));
//    Serial.println(F("should appear in the library header (Adafruit_TFT.h)."));
//    Serial.println(F("If using the breakout board, it should NOT be #defined!"));
//    Serial.println(F("Also if using the breakout, double-check that all wiring"));
//    Serial.println(F("matches the tutorial."));
//    return;
//  }

Serial.begin(9600);
  long x= minutesDiff(2015,12,24,23,59, 2017,1,1,0,0 );
  Serial.println(x);

  x= minutesDiff(2015,12,31,0,1, 2016,1,1,0,1);
  Serial.println(x);

  x=minutesDiff(2016,2,28,23,59, 2016,3,1,0,0 );
  Serial.println(x);

  x=minutesDiff(2016,12,31,23,59, 2017,1,1,0,0);
  Serial.println(x);

  x=minutesDiff(2017,2,28,23,59, 2017,3,1,0,0 );
  Serial.println(x);

  tft.begin(identifier);

tft.fillScreen(BLACK);
  Serial.println(F("Done!"));
}
void drawUrsaMinor() {
//Ursa Minor
tft.fillCircle(46, 74 + shift, 5, GREEN);
tft.drawLine(46, 74 + shift, 66, 81 + shift, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(66, 81 + shift, 2, BLUE);
tft.drawLine(66, 81 + shift, 98, 86 + shift, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(98, 86 + shift, 2, MAGENTA);
tft.drawLine(98, 86 + shift, 120, 79 + shift, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(120, 79 + shift, 2, YELLOW);
tft.drawLine(120, 79 + shift, 135, 55 + shift, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(135, 55 + shift, 4, RED);
tft.drawLine(135, 55 + shift, 154, 67 + shift, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(154, 67 + shift, 3, ORANGE);
tft.drawLine(154, 67 + shift, 134, 97 + shift, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(134, 97 + shift, 1, CYAN);
tft.drawLine(134, 97 + shift, 120, 79 + shift, CYAN);
//Serial.println("Drew Line 6");

}
void blankUrsaMinor() {
// blank Ursa Minor
tft.fillCircle(46, 74 + shift, 5, BLACK);
tft.drawLine(46, 74 + shift, 66, 81 + shift, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(66, 81 + shift, 2, BLACK);
tft.drawLine(66, 81 + shift, 98, 86 + shift, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(98, 86 + shift, 2, BLACK);
tft.drawLine(98, 86 + shift, 120, 79 + shift, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(120, 79 + shift, 2, BLACK);
tft.drawLine(120, 79 + shift, 135, 55 + shift, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(135, 55 + shift, 4, BLACK);
tft.drawLine(135, 55 + shift, 154, 67 + shift, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(154, 67 + shift, 3, BLACK);
tft.drawLine(154, 67 + shift, 134, 97 + shift, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(134, 97 + shift, 1, BLACK);
tft.drawLine(134, 97 + shift, 120, 79 + shift, BLACK);
//Serial.println("Drew Line 6");
 
}
void drawDraco() {
//Draco
tft.fillCircle(46, 8 + shift, 1, GREEN);
tft.drawLine(46, 8 + shift, 86, 26 + shift, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(86, 26 + shift, 2, BLUE);
tft.drawLine(86, 26 + shift, 148, 40 + shift, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(148, 40 + shift, 2, MAGENTA);
tft.drawLine(148, 40 + shift, 225, 62 + shift, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(225, 62 + shift, 2, YELLOW);
tft.drawLine(225, 62 + shift, 231, 94 + shift, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(231, 94 + shift, 2, RED);
tft.drawLine(231, 94 + shift, 202, 115 + shift, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(202, 115 + shift, 3, ORANGE);
tft.drawLine(202, 115 + shift, 160, 138 + shift, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(160, 138 + shift, 2, CYAN);
tft.drawLine(160, 138 + shift, 89, 143 + shift, CYAN);
//Serial.println("Drew Line 7");

tft.fillCircle(89, 143 + shift, 2, GREEN);
tft.drawLine(89, 143 + shift, 55, 157 + shift, GREEN);
//Serial.println("Drew Line 8");

tft.fillCircle(55, 157 + shift, 2, BLUE);
tft.drawLine(55, 157 + shift, 47, 181 + shift, BLUE);
//Serial.println("Drew Line 9");

tft.fillCircle(47, 181 + shift, 2, MAGENTA);
tft.drawLine(47, 181 + shift, 79, 192 + shift, MAGENTA);
//Serial.println("Drew Line 10");

tft.fillCircle(79, 192 + shift, 3, YELLOW);
tft.drawLine(79, 192 + shift, 180, 200 + shift, YELLOW);
//Serial.println("Drew Line 11");

tft.fillCircle(180, 200 + shift, 2, RED);
tft.drawLine(180, 200 + shift, 210, 183 + shift, RED);
//Serial.println("Drew Line 12");

tft.fillCircle(210, 183 + shift, 1, ORANGE);
tft.drawLine(210, 183 + shift, 230, 193 + shift, ORANGE);
//Serial.println("Drew Line 13");

tft.fillCircle(230, 193 + shift, 3, CYAN);
tft.drawLine(230, 193 + shift, 219, 230 + shift, CYAN);
//Serial.println("Drew Line 14");

tft.fillCircle(219, 230 + shift, 4, CYAN);
tft.drawLine(219, 230 + shift, 180, 200 + shift, CYAN);
//Serial.println("Drew Line 15");

}

void blankDraco() {
// blank Draco
tft.fillCircle(46, 8 + shift, 1, BLACK);
tft.drawLine(46, 8 + shift, 86, 26 + shift, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(86, 26 + shift, 2, BLACK);
tft.drawLine(86, 26 + shift, 148, 40 + shift, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(148, 40 + shift, 2, BLACK);
tft.drawLine(148, 40 + shift, 225, 62 + shift, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(225, 62 + shift, 2, BLACK);
tft.drawLine(225, 62 + shift, 231, 94 + shift, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(231, 94 + shift, 2, BLACK);
tft.drawLine(231, 94 + shift, 202, 115 + shift, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(202, 115 + shift, 3, BLACK);
tft.drawLine(202, 115 + shift, 160, 138 + shift, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(160, 138 + shift, 2, BLACK);
tft.drawLine(160, 138 + shift, 89, 143 + shift, BLACK);
//Serial.println("Drew Line 7");

tft.fillCircle(89, 143 + shift, 2, BLACK);
tft.drawLine(89, 143 + shift, 55, 157 + shift, BLACK);
//Serial.println("Drew Line 8");

tft.fillCircle(55, 157 + shift, 2, BLACK);
tft.drawLine(55, 157 + shift, 47, 181 + shift, BLACK);
//Serial.println("Drew Line 9");

tft.fillCircle(47, 181 + shift, 2, BLACK);
tft.drawLine(47, 181 + shift, 79, 192 + shift, BLACK);
//Serial.println("Drew Line 10");

tft.fillCircle(79, 192 + shift, 3, BLACK);
tft.drawLine(79, 192 + shift, 180, 200 + shift, BLACK);
//Serial.println("Drew Line 11");

tft.fillCircle(180, 200 + shift, 2, BLACK);
tft.drawLine(180, 200 + shift, 210, 183 + shift, BLACK);
//Serial.println("Drew Line 12");

tft.fillCircle(210, 183 + shift, 1, BLACK);
tft.drawLine(210, 183 + shift, 230, 193 + shift, BLACK);
//Serial.println("Drew Line 13");

tft.fillCircle(230, 193 + shift, 3, BLACK);
tft.drawLine(230, 193 + shift, 219, 230 + shift, BLACK);
//Serial.println("Drew Line 14");

tft.fillCircle(219, 230 + shift, 4, BLACK);
tft.drawLine(219, 230 + shift, 180, 200 + shift, BLACK);
//Serial.println("Drew Line 15");
}

void drawCepheus() {
//Cepheus
tft.fillCircle(163, 115  + shift + 320, 2, GREEN);
tft.drawLine(163 , 115 + shift + 320, 52, 30 + shift + 320, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(52 , 30 + shift + 320, 2, BLUE);
tft.drawLine(52 , 30 + shift + 320, 75 , 190 + shift + 320, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(75 , 190 + shift + 320, 2, MAGENTA);
tft.drawLine(75 , 190 + shift + 320, 163 , 115 + shift + 320, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(163 , 115 + shift + 320, 3, YELLOW);
tft.drawLine(163 , 115 + shift + 320, 205 , 210 + shift + 320, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(205 , 210 + shift + 320, 2, RED);
tft.drawLine(205 , 210 + shift + 320, 130 , 300 + shift + 320, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(130 , 300 + shift + 320, 2, RED);
tft.drawLine(130 , 300 + shift + 320, 75 , 190 + shift + 320, RED);
//Serial.println("Drew Line 6");
}

void blankCepheus() {
// blank Cepheus
tft.fillCircle(163, 115  + shift + 320, 2, BLACK);
tft.drawLine(163 , 115 + shift + 320, 52, 30 + shift + 320, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(52 , 30 + shift + 320, 2, BLACK);
tft.drawLine(52 , 30 + shift + 320, 75 , 190 + shift + 320, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(75 , 190 + shift + 320, 2, BLACK);
tft.drawLine(75 , 190 + shift + 320, 163 , 115 + shift + 320, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(163 , 115 + shift + 320, 3, BLACK);
tft.drawLine(163 , 115 + shift + 320, 205 , 210 + shift + 320, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(205 , 210 + shift + 320, 2, BLACK);
tft.drawLine(205 , 210 + shift + 320, 130 , 300 + shift + 320, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(130 , 300 + shift + 320, 2, BLACK);
tft.drawLine(130 , 300 + shift + 320, 75 , 190 + shift + 320, BLACK);
//Serial.println("Drew Line 6");
}

void drawCassiopeia() {
//Cassiopeia
tft.fillCircle(160, 280 + shift + 640, 4, GREEN);
tft.drawLine(160, 280 + shift + 640, 52, 255 + shift + 640, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(52, 255 + shift + 640, 4, BLUE);
tft.drawLine(52, 255 + shift + 640, 85, 178 + shift + 640, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(85, 178 + shift + 640, 4, MAGENTA);
tft.drawLine(85, 178 + shift + 640, 28, 130 + shift + 640, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(28, 130 + shift + 640, 3, YELLOW);
tft.drawLine(28, 130 + shift + 640, 60, 35 + shift + 640, YELLOW);
tft.fillCircle(60, 35 + shift + 640, 2, YELLOW);
//Serial.println("Drew Line 4");
}

void blankCassiopeia() {
//blank Cassiopeia
tft.fillCircle(160, 280 + shift + 640, 4, BLACK);
tft.drawLine(160, 280 + shift + 640, 52, 255 + shift + 640, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(52, 255 + shift + 640, 4, BLACK);
tft.drawLine(52, 255 + shift + 640, 85, 178 + shift + 640, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(85, 178 + shift + 640, 4, BLACK);
tft.drawLine(85, 178 + shift + 640, 28, 130 + shift + 640, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(28, 130 + shift + 640, 3, BLACK);
tft.drawLine(28, 130 + shift + 640, 60, 35 + shift + 640, BLACK);
tft.fillCircle(60, 35 + shift + 640, 2, BLACK);
//Serial.println("Drew Line 4");
}

void drawCamelopardalis() {
//draw Camelopardalis
tft.fillCircle(37, 289 + shift + 960, 2, GREEN);
tft.drawLine(37, 289 + shift + 960, 52, 240 + shift + 960, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(52, 240 + shift + 960, 1, BLUE);
tft.drawLine(52, 240 + shift + 960, 74, 140 + shift + 960, BLUE);
tft.fillCircle(74, 140 + shift + 960, 2, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(139, 182 + shift + 960, 1, MAGENTA);
tft.drawLine(139, 182 + shift + 960, 74, 140 + shift + 960, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(139, 182 + shift + 960, 2, YELLOW);
tft.drawLine(139, 182 + shift + 960, 190, 60 + shift + 960, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(139, 182 + shift + 960, 2, CYAN);
tft.drawLine(139, 182 + shift + 960, 37, 289 + shift + 960, CYAN);
}

void blankCamelopardalis() {
//blank Camelopardalis
tft.fillCircle(37, 289 + shift + 960, 2, BLACK);
tft.drawLine(37, 289 + shift + 960, 52, 240 + shift + 960, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(52, 240 + shift + 960, 1, BLACK);
tft.drawLine(52, 240 + shift + 960, 74, 140 + shift + 960, BLACK);
tft.fillCircle(74, 140 + shift + 960, 2, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(139, 182 + shift + 960, 1, BLACK);
tft.drawLine(139, 182 + shift + 960, 74, 140 + shift + 960, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(139, 182 + shift + 960, 2, BLACK);
tft.drawLine(139, 182 + shift + 960, 190, 60 + shift + 960, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(139, 182 + shift + 960, 2, BLACK);
tft.drawLine(139, 182 + shift + 960, 37, 289 + shift + 960, BLACK);
}

void drawLynx() {
// draw Lynx
tft.fillCircle(200, 20 + shift + 1280, 3, GREEN);
tft.drawLine(200, 20 + shift + 1280, 215, 60 + shift + 1280, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(215, 60 + shift + 1280, 2, BLUE);
tft.drawLine(215, 60 + shift + 1280, 205, 95 + shift + 1280, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(205, 95 + shift + 1280, 2, MAGENTA);
tft.drawLine(205, 95 + shift + 1280, 220, 115 + shift + 1280, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(220, 115 + shift + 1280, 2, YELLOW);
tft.drawLine(220, 115 + shift + 1280, 190, 150 + shift + 1280, YELLOW);
//Serial.println("Drew Line 4");
//
tft.fillCircle(190, 150 + shift + 1280, 2, RED);
tft.drawLine(190, 150 + shift + 1280, 180, 200 + shift + 1280, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(180, 200 + shift + 1280, 1, ORANGE);
tft.drawLine(180, 200 + shift + 1280, 197, 240 + shift + 1280, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(197, 240 + shift + 1280, 2, CYAN);
tft.drawLine(197, 240 + shift + 1280, 185, 270 + shift + 1280, CYAN);
tft.fillCircle(185, 270 + shift + 1280, 1, CYAN);
//Serial.println("Drew Line 7");
}

void blankLynx() {
// blank Lynx
tft.fillCircle(200, 20 + shift + 1280, 3, BLACK);
tft.drawLine(200, 20 + shift + 1280, 215, 60 + shift + 1280, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(215, 60 + shift + 1280, 2, BLACK);
tft.drawLine(215, 60 + shift + 1280, 205, 95 + shift + 1280, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(205, 95 + shift + 1280, 2, BLACK);
tft.drawLine(205, 95 + shift + 1280, 220, 115 + shift + 1280, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(220, 115 + shift + 1280, 2, BLACK);
tft.drawLine(220, 115 + shift + 1280, 190, 150 + shift + 1280, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(190, 150 + shift + 1280, 2, BLACK);
tft.drawLine(190, 150 + shift + 1280, 180, 200 + shift + 1280, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(180, 200 + shift + 1280, 1, BLACK);
tft.drawLine(180, 200 + shift + 1280, 197, 240 + shift + 1280, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(197, 240 + shift + 1280, 2, BLACK);
tft.drawLine(197, 240 + shift + 1280, 185, 270 + shift + 1280, BLACK);
tft.fillCircle(185, 270 + shift + 1280, 1, BLACK);
//Serial.println("Drew Line 7");

}

void drawUrsaMajor() {
//draw Ursa Major (Big Dipper)
tft.fillCircle(200, 17 + shift + 1600, 5, GREEN);
tft.drawLine(200, 17 + shift + 1600, 170, 45 + shift + 1600, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(170, 45 + shift + 1600, 4, BLUE);
tft.drawLine(170, 45 + shift + 1600, 130, 50 + shift + 1600, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(130, 50 + shift + 1600, 5, MAGENTA);
tft.drawLine(130, 50 + shift + 1600, 90, 60 + shift + 1600, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(90, 60 + shift + 1600, 2, YELLOW);
tft.drawLine(90, 60 + shift + 1600, 57, 117 + shift + 1600, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(57, 117 + shift + 1600, 3, RED);
tft.drawLine(57, 117 + shift + 1600, 30, 82 + shift + 1600, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(30, 82 + shift + 1600, 3, ORANGE);
tft.drawLine(30, 82 + shift + 1600, 55, 45 + shift + 1600, ORANGE);
//Serial.println("Drew Line 5");

tft.fillCircle(55, 45 + shift + 1600, 3, CYAN);
tft.drawLine(55, 45 + shift + 1600, 90, 60 + shift + 1600, CYAN);
//Serial.println("Drew Line 5");
}

void blankUrsaMajor() {
//blank Ursa Major (Big Dipper)
tft.fillCircle(200, 17 + shift + 1600, 5, BLACK);
tft.drawLine(200, 17 + shift + 1600, 170, 45 + shift + 1600, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(170, 45 + shift + 1600, 4, BLACK);
tft.drawLine(170, 45 + shift + 1600, 130, 50 + shift + 1600, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(130, 50 + shift + 1600, 5, BLACK);
tft.drawLine(130, 50 + shift + 1600, 90, 60 + shift + 1600, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(90, 60 + shift + 1600, 2, BLACK);
tft.drawLine(90, 60 + shift + 1600, 57, 117 + shift + 1600, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(57, 117 + shift + 1600, 3, BLACK);
tft.drawLine(57, 117 + shift + 1600, 30, 82 + shift + 1600, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(30, 82 + shift + 1600, 3, BLACK);
tft.drawLine(30, 82 + shift + 1600, 55, 45 + shift + 1600, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(55, 45 + shift + 1600, 3, BLACK);
tft.drawLine(55, 45 + shift + 1600, 90, 60 + shift + 1600, BLACK);
//Serial.println("Drew Line 5");
}

void drawUrsaMinor2() {
//Ursa Minor
tft.fillCircle(46, 74 + shift + 1920, 5, GREEN);
tft.drawLine(46, 74 + shift + 1920, 66, 81 + shift + 1920, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(66, 81 + shift + 1920, 2, BLUE);
tft.drawLine(66, 81 + shift + 1920, 98, 86 + shift + 1920, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(98, 86 + shift + 1920, 2, MAGENTA);
tft.drawLine(98, 86 + shift +  + 1920, 120, 79 + shift + 1920, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(120, 79 + shift + 1920, 2, YELLOW);
tft.drawLine(120, 79 + shift + 1920, 135, 55 + shift + 1920, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(135, 55 + shift + 1920, 4, RED);
tft.drawLine(135, 55 + shift + 1920, 154, 67 + shift + 1920, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(154, 67 + shift + 1920, 3, ORANGE);
tft.drawLine(154, 67 + shift + 1920, 134, 97 + shift + 1920, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(134, 97 + shift + 1920, 1, CYAN);
tft.drawLine(134, 97 + shift + 1920, 120, 79 + shift + 1920, CYAN);
//Serial.println("Drew Line 6");

}
void blankUrsaMinor2() {
// blank Ursa Minor
tft.fillCircle(46, 74 + shift + 1920, 5, BLACK);
tft.drawLine(46, 74 + shift + 1920, 66, 81 + shift + 1920, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(66, 81 + shift + 1920, 2, BLACK);
tft.drawLine(66, 81 + shift + 1920, 98, 86 + shift + 1920, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(98, 86 + shift + 1920, 2, BLACK);
tft.drawLine(98, 86 + shift + 1920, 120, 79 + shift + 1920, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(120, 79 + shift + 1920, 2, BLACK);
tft.drawLine(120, 79 + shift + 1920, 135, 55 + shift + 1920, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(135, 55 + shift + 1920, 4, BLACK);
tft.drawLine(135, 55 + shift + 1920, 154, 67 + shift + 1920, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(154, 67 + shift + 1920, 3, BLACK);
tft.drawLine(154, 67 + shift + 1920, 134, 97 + shift + 1920, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(134, 97 + shift + 1920, 1, BLACK);
tft.drawLine(134, 97 + shift + 1920, 120, 79 + shift + 1920, BLACK);
//Serial.println("Drew Line 6");
 
}
void drawDraco2() {
//Draco
tft.fillCircle(46, 8 + shift + 1920, 1, GREEN);
tft.drawLine(46, 8 + shift + 1920, 86, 26 + shift + 1920, GREEN);
//Serial.println("Drew Line 1");

tft.fillCircle(86, 26 + shift + 1920, 2, BLUE);
tft.drawLine(86, 26 + shift + 1920, 148, 40 + shift + 1920, BLUE);
//Serial.println("Drew Line 2");

tft.fillCircle(148, 40 + shift + 1920, 2, MAGENTA);
tft.drawLine(148, 40 + shift + 1920, 225, 62 + shift + 1920, MAGENTA);
//Serial.println("Drew Line 3");

tft.fillCircle(225, 62 + shift + 1920, 2, YELLOW);
tft.drawLine(225, 62 + shift + 1920, 231, 94 + shift + 1920, YELLOW);
//Serial.println("Drew Line 4");

tft.fillCircle(231, 94 + shift + 1920, 2, RED);
tft.drawLine(231, 94 + shift + 1920, 202, 115 + shift + 1920, RED);
//Serial.println("Drew Line 5");

tft.fillCircle(202, 115 + shift + 1920, 3, ORANGE);
tft.drawLine(202, 115 + shift + 1920, 160, 138 + shift + 1920, ORANGE);
//Serial.println("Drew Line 6");

tft.fillCircle(160, 138 + shift + 1920, 2, CYAN);
tft.drawLine(160, 138 + shift + 1920, 89, 143 + shift + 1920, CYAN);
//Serial.println("Drew Line 7");

tft.fillCircle(89, 143 + shift + 1920, 2, GREEN);
tft.drawLine(89, 143 + shift + 1920, 55, 157 + shift + 1920, GREEN);
//Serial.println("Drew Line 8");

tft.fillCircle(55, 157 + shift + 1920, 2, BLUE);
tft.drawLine(55, 157 + shift + 1920, 47, 181 + shift + 1920, BLUE);
//Serial.println("Drew Line 9");

tft.fillCircle(47, 181 + shift + 1920, 2, MAGENTA);
tft.drawLine(47, 181 + shift + 1920, 79, 192 + shift + 1920, MAGENTA);
//Serial.println("Drew Line 10");

tft.fillCircle(79, 192 + shift + 1920, 3, YELLOW);
tft.drawLine(79, 192 + shift + 1920, 180, 200 + shift + 1920, YELLOW);
//Serial.println("Drew Line 11");

tft.fillCircle(180, 200 + shift + 1920, 2, RED);
tft.drawLine(180, 200 + shift + 1920, 210, 183 + shift + 1920, RED);
//Serial.println("Drew Line 12");

tft.fillCircle(210, 183 + shift + 1920, 1, ORANGE);
tft.drawLine(210, 183 + shift + 1920, 230, 193 + shift + 1920, ORANGE);
//Serial.println("Drew Line 13");

tft.fillCircle(230, 193 + shift + 1920, 3, CYAN);
tft.drawLine(230, 193 + shift + 1920, 219, 230 + shift + 1920, CYAN);
//Serial.println("Drew Line 14");

tft.fillCircle(219, 230 + shift + 1920, 4, CYAN);
tft.drawLine(219, 230 + shift + 1920, 180, 200 + shift + 1920, CYAN);
//Serial.println("Drew Line 15");

}

void blankDraco2() {
// blank Draco
tft.fillCircle(46, 8 + shift + 1920, 1, BLACK);
tft.drawLine(46, 8 + shift + 1920, 86, 26 + shift + 1920, BLACK);
//Serial.println("Drew Line 1");

tft.fillCircle(86, 26 + shift + 1920, 2, BLACK);
tft.drawLine(86, 26 + shift + 1920, 148, 40 + shift + 1920, BLACK);
//Serial.println("Drew Line 2");

tft.fillCircle(148, 40 + shift + 1920, 2, BLACK);
tft.drawLine(148, 40 + shift + 1920, 225, 62 + shift + 1920, BLACK);
//Serial.println("Drew Line 3");

tft.fillCircle(225, 62 + shift + 1920, 2, BLACK);
tft.drawLine(225, 62 + shift + 1920, 231, 94 + shift + 1920, BLACK);
//Serial.println("Drew Line 4");

tft.fillCircle(231, 94 + shift + 1920, 2, BLACK);
tft.drawLine(231, 94 + shift + 1920, 202, 115 + shift + 1920, BLACK);
//Serial.println("Drew Line 5");

tft.fillCircle(202, 115 + shift + 1920, 3, BLACK);
tft.drawLine(202, 115 + shift + 1920, 160, 138 + shift + 1920, BLACK);
//Serial.println("Drew Line 6");

tft.fillCircle(160, 138 + shift + 1920, 2, BLACK);
tft.drawLine(160, 138 + shift + 1920, 89, 143 + shift + 1920, BLACK);
//Serial.println("Drew Line 7");

tft.fillCircle(89, 143 + shift + 1920, 2, BLACK);
tft.drawLine(89, 143 + shift + 1920, 55, 157 + shift + 1920, BLACK);
//Serial.println("Drew Line 8");

tft.fillCircle(55, 157 + shift + 1920, 2, BLACK);
tft.drawLine(55, 157 + shift + 1920, 47, 181 + shift + 1920, BLACK);
//Serial.println("Drew Line 9");

tft.fillCircle(47, 181 + shift + 1920, 2, BLACK);
tft.drawLine(47, 181 + shift + 1920, 79, 192 + shift + 1920, BLACK);
//Serial.println("Drew Line 10");

tft.fillCircle(79, 192 + shift + 1920, 3, BLACK);
tft.drawLine(79, 192 + shift + 1920, 180, 200 + shift + 1920, BLACK);
//Serial.println("Drew Line 11");

tft.fillCircle(180, 200 + shift + 1920, 2, BLACK);
tft.drawLine(180, 200 + shift + 1920, 210, 183 + shift + 1920, BLACK);
//Serial.println("Drew Line 12");

tft.fillCircle(210, 183 + shift + 1920, 1, BLACK);
tft.drawLine(210, 183 + shift + 1920, 230, 193 + shift + 1920, BLACK);
//Serial.println("Drew Line 13");

tft.fillCircle(230, 193 + shift + 1920, 3, BLACK);
tft.drawLine(230, 193 + shift + 1920, 219, 230 + shift + 1920, BLACK);
//Serial.println("Drew Line 14");

tft.fillCircle(219, 230 + shift + 1920, 4, BLACK);
tft.drawLine(219, 230 + shift + 1920, 180, 200 + shift + 1920, BLACK);
//Serial.println("Drew Line 15");
}

void loop(void) {

  int val = 0;
  val = map(val, -80, 80, -12, 12);

   //Blanking Constellation.
   //If statements determine which one(s) to draw when
 
  if(shift > -640 ){
  blankUrsaMinor();
  blankDraco();
  }
 
  if(shift > -960 && shift < 0)
  blankCepheus();

  if(shift > -1280 && shift < -320)
  blankCassiopeia();
 
   if(shift > -1600 && shift < -640)
  blankCamelopardalis();
 
    if(shift > -1920 && shift < -960)
  blankLynx();
 
   if(shift > -2240  && shift < -1280 )
  blankUrsaMajor();
 
  //Create a second copy of draco and uMinor to follow uMajor
   if(shift > -2560 ){
  blankUrsaMinor2();
  blankDraco2();
}
 
    if(shift < -1900 ){ //reset at the end
  shift=0;
  }
 
Serial.println(shift); //only for debugging

//This shifts everything to the new position to draw visible lines
  shift-=20;
     
   if(shift > -640){
  drawUrsaMinor();
  drawDraco();
   }
  if(shift >-960 && shift <0 )
  drawCepheus();

  if(shift > -1280 && shift < -320)
  drawCassiopeia();

  if(shift > -1600 && shift < -640)
  drawCamelopardalis();

  if(shift > -1920 && shift < -960)
  drawLynx();
 
  if(shift > -2240  && shift < -1280 )
  drawUrsaMajor();

//Create a second draco and uMinor to follow uMajor
    if(shift > -2560 && shift < -1600 ){
  drawUrsaMinor2();
  drawDraco2();
  }
   delay(500);  //we will change this delay to make it faster or slower depending on the GPS signal.

    // print position, altitude, speed, time/date, and satellites:
  printGPSInfo();

  // "Smart delay" looks for GPS data while the Arduino's not doing anything else
  smartDelay(1000);

   
} //end loop()

void printGPSInfo(void)
{
  Serial.print("Lat: "); Serial.println(tinyGPS.location.lat(), 6);
  Serial.print("Long: "); Serial.println(tinyGPS.location.lng(), 6);
  Serial.print("Alt: "); Serial.println(tinyGPS.altitude.feet());
  Serial.print("Course: "); Serial.println(tinyGPS.course.deg());
  Serial.print("Speed: "); Serial.println(tinyGPS.speed.mph());
  Serial.print("Date: "); printDate();
  Serial.print("Time: "); printTime();
  Serial.print("Sats: "); Serial.println(tinyGPS.satellites.value());
  Serial.println();
}
static void smartDelay(unsigned long ms)
{
  unsigned long start = millis();
  do
  {
    // If data has come in from the GPS module
    while (gpsPort.available())
      tinyGPS.encode(gpsPort.read()); // Send it to the encode function
  } while (millis() - start < ms);
}

// printDate() formats the date into dd/mm/yy.
void printDate(void)
{
  Serial.print(tinyGPS.date.day());
  Serial.print("/");
  Serial.print(tinyGPS.date.month());
  Serial.print("/");
  Serial.println(tinyGPS.date.year());
  }
// printTime() formats the time into "hh:mm:ss", and prints leading 0's
// where they're called for.
void printTime(void)
{
  Serial.print(tinyGPS.time.hour());
  Serial.print(":");
  if (tinyGPS.time.minute() < 10) Serial.print('0');
  Serial.print(tinyGPS.time.minute());
  Serial.print(":");
  if (tinyGPS.time.second() < 10) Serial.print('0');
  Serial.println(tinyGPS.time.second());
  }








 
