// IMPORTANT: Adafruit_TFTLCD LIBRARY MUST BE SPECIFICALLY
// CONFIGURED FOR EITHER THE TFT SHIELD OR THE BREAKOUT BOARD.
// SEE RELEVANT COMMENTS IN Adafruit_TFTLCD.h FOR SETUP.

#include <Adafruit_GFX.h>    // Core graphics library
#include <Adafruit_TFTLCD.h> // Hardware-specific library

// The control pins for the LCD can be assigned to any digital or
// analog pins...but we'll use the analog pins as this allows us to
// double up the pins with the touch screen (see the TFT paint example).
#define LCD_CS A3 // Chip Select goes to Analog 3
#define LCD_CD A2 // Command/Data goes to Analog 2
#define LCD_WR A1 // LCD Write goes to Analog 1
#define LCD_RD A0 // LCD Read goes to Analog 0

#define LCD_RESET A4 // Can alternately just connect to Arduino's reset pin

// When using the BREAKOUT BOARD only, use these 8 data lines to the LCD:
// For the Arduino Uno, Duemilanove, Diecimila, etc.:
//   D0 connects to digital pin 8  (Notice these are
//   D1 connects to digital pin 9   NOT in order!)
//   D2 connects to digital pin 2
//   D3 connects to digital pin 3
//   D4 connects to digital pin 4
//   D5 connects to digital pin 5
//   D6 connects to digital pin 6
//   D7 connects to digital pin 7
// For the Arduino Mega, use digital pins 22 through 29
// (on the 2-row header at the end of the board).

// Assign human-readable names to some common 16-bit color values:
#define BLACK   0x0000
#define BLUE    0x001F
#define RED     0xF800
#define GREEN   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define YELLOW  0xFFE0
#define WHITE   0xFFFF
#define ORANGE  0xF700


Adafruit_TFTLCD tft(LCD_CS, LCD_CD, LCD_WR, LCD_RD, LCD_RESET);
// If using the shield, all control and data lines are fixed, and
// a simpler declaration can optionally be used:
// Adafruit_TFTLCD tft;

void setup(void) {
  Serial.begin(9600);
  Serial.println(F("TFT LCD test"));

#ifdef USE_ADAFRUIT_SHIELD_PINOUT
  Serial.println(F("Using Adafruit 2.8\" TFT Arduino Shield Pinout"));
#else
  Serial.println(F("Using Adafruit 2.8\" TFT Breakout Board Pinout"));
#endif

  Serial.print("TFT size is "); Serial.print(tft.width()); Serial.print("x"); Serial.println(tft.height());

  tft.reset();

  uint16_t identifier = tft.readID();

  if(identifier == 0x9325) {
    Serial.println(F("Found ILI9325 LCD driver"));
  } else if(identifier == 0x9328) {
    Serial.println(F("Found ILI9328 LCD driver"));
  } else if(identifier == 0x7575) {
    Serial.println(F("Found HX8347G LCD driver"));
  } else if(identifier == 0x9341) {
    Serial.println(F("Found ILI9341 LCD driver"));
  } else if(identifier == 0x8357) {
    Serial.println(F("Found HX8357D LCD driver"));
  } else {
    Serial.print(F("Unknown LCD driver chip: "));
    Serial.println(identifier, HEX);
    Serial.println(F("If using the Adafruit 2.8\" TFT Arduino shield, the line:"));
    Serial.println(F("  #define USE_ADAFRUIT_SHIELD_PINOUT"));
    Serial.println(F("should appear in the library header (Adafruit_TFT.h)."));
    Serial.println(F("If using the breakout board, it should NOT be #defined!"));
    Serial.println(F("Also if using the breakout, double-check that all wiring"));
    Serial.println(F("matches the tutorial."));
    return;
  }

  tft.begin(identifier);

//  Serial.println(F("Benchmark                Time (microseconds)"));
//
//  Serial.print(F("Screen fill              "));
//  Serial.println(testFillScreen());
//  delay(500);
//
//  Serial.print(F("Text                     "));
//  Serial.println(testText());
//  delay(3000);
//
//  Serial.print(F("Lines                    "));
//  Serial.println(testLines(CYAN));
//  delay(500);


//  Serial.print(F("Horiz/Vert Lines         "));
//  Serial.println(testFastLines(RED, BLUE));
//  delay(500);
//
//  Serial.print(F("Rectangles (outline)     "));
//  Serial.println(testRects(GREEN));
//  delay(500);
//
//  Serial.print(F("Rectangles (filled)      "));
//  Serial.println(testFilledRects(YELLOW, MAGENTA));
//  delay(500);
//
//  Serial.print(F("Circles (filled)         "));
//  Serial.println(testFilledCircles(10, MAGENTA));
//
//  Serial.print(F("Circles (outline)        "));
//  Serial.println(testCircles(10, WHITE));
//  delay(500);
//
//  Serial.print(F("Triangles (outline)      "));
//  Serial.println(testTriangles());
//  delay(500);
//
//  Serial.print(F("Triangles (filled)       "));
//  Serial.println(testFilledTriangles());
//  delay(500);
//
//  Serial.print(F("Rounded rects (outline)  "));
//  Serial.println(testRoundRects());
//  delay(500);
//
//  Serial.print(F("Rounded rects (filled)   "));
//  Serial.println(testFilledRoundRects());
//  delay(500);

  Serial.println(F("Done!"));
}

void loop(void) {

tft.fillScreen(BLACK);
Serial.println("Made screen black");
//Ursa Minor
//  tft.fillCircle(x, y, radius, color);

tft.fillCircle(46, 74, 5, GREEN);
tft.drawLine(46, 74, 66, 81, GREEN);
Serial.println("Drew Line 1");

tft.fillCircle(66, 81, 2, BLUE);
tft.drawLine(66, 81, 98, 86, BLUE);
Serial.println("Drew Line 2");

tft.fillCircle(98, 86, 2, MAGENTA);
tft.drawLine(98, 86, 120, 79, MAGENTA);
Serial.println("Drew Line 3");

tft.fillCircle(120, 79, 2, YELLOW);
tft.drawLine(120, 79, 135, 55, YELLOW);
Serial.println("Drew Line 4");

tft.fillCircle(135, 55, 4, RED);
tft.drawLine(135, 55, 154, 67, RED);
Serial.println("Drew Line 5");

tft.fillCircle(154, 67, 3, ORANGE);
tft.drawLine(154, 67, 134, 97, ORANGE);
Serial.println("Drew Line 6");

tft.fillCircle(134, 97, 1, CYAN);
tft.drawLine(134, 97, 120, 79, CYAN);
Serial.println("Drew Line 6");

delay(5000);


int shift=0;
//Draco
tft.fillCircle(46, 8, 1, GREEN);
tft.drawLine(46, 8, 86, 26, GREEN);
Serial.println("Drew Line 1");

tft.fillCircle(86, 26, 2, BLUE);
tft.drawLine(86, 26, 148, 40, BLUE);
Serial.println("Drew Line 2");

tft.fillCircle(148, 40, 2, MAGENTA);
tft.drawLine(148, 40, 225, 62, MAGENTA);
Serial.println("Drew Line 3");

tft.fillCircle(225, 62, 2, YELLOW);
tft.drawLine(225, 62, 231, 94, YELLOW);
Serial.println("Drew Line 4");

tft.fillCircle(231, 94, 2, RED);
tft.drawLine(231, 94, 202, 115, RED);
Serial.println("Drew Line 5");

tft.fillCircle(202, 115, 3, ORANGE);
tft.drawLine(202, 115, 160, 138, ORANGE);
Serial.println("Drew Line 6");

tft.fillCircle(160, 138, 2, CYAN);
tft.drawLine(160, 138, 89, 143, CYAN);
Serial.println("Drew Line 7");

tft.fillCircle(89, 143, 2, GREEN);
tft.drawLine(89, 143, 55, 157, GREEN);
Serial.println("Drew Line 8");

tft.fillCircle(55, 157, 2, BLUE);
tft.drawLine(55, 157, 47, 181, BLUE);
Serial.println("Drew Line 9");

tft.fillCircle(47, 181, 2, MAGENTA);
tft.drawLine(47, 181, 79, 192, MAGENTA);
Serial.println("Drew Line 10");

tft.fillCircle(79, 192, 3, YELLOW);
tft.drawLine(79, 192, 180, 200, YELLOW);
Serial.println("Drew Line 11");

tft.fillCircle(180, 200, 2, RED);
tft.drawLine(180, 200, 210, 183, RED);
Serial.println("Drew Line 12");

tft.fillCircle(210, 183, 1, ORANGE);
tft.drawLine(210, 183, 230, 193, ORANGE);
Serial.println("Drew Line 13");

tft.fillCircle(230, 193, 3, CYAN);
tft.drawLine(230, 193, 219, 230, CYAN);
Serial.println("Drew Line 14");

tft.fillCircle(219, 230, 4, CYAN);
tft.drawLine(219, 230, 180, 200, CYAN);
Serial.println("Drew Line 15");

delay(5000);

tft.fillScreen(BLACK);
Serial.println("Made screen black");

//Cepheus
tft.fillCircle(163, 115, 2, GREEN);
tft.drawLine(163, 115, 52, 30, GREEN);
Serial.println("Drew Line 1");

tft.fillCircle(52, 30, 2, BLUE);
tft.drawLine(52, 30, 75, 190, BLUE);
Serial.println("Drew Line 2");

tft.fillCircle(75, 190, 2, MAGENTA);
tft.drawLine(75, 190, 163, 115, MAGENTA);
Serial.println("Drew Line 3");

tft.fillCircle(163, 115, 3, YELLOW);
tft.drawLine(163, 115, 205, 210, YELLOW);
Serial.println("Drew Line 4");

tft.fillCircle(205, 210, 2, RED);
tft.drawLine(205, 210, 130, 300, RED);
Serial.println("Drew Line 5");

tft.fillCircle(130, 300, 2, RED);
tft.drawLine(130, 300, 75, 190, RED);
Serial.println("Drew Line 6");

delay(5000);

tft.fillScreen(BLACK);
Serial.println("Made screen black");

//Cassiopeia
tft.fillCircle(218, 166, 4, GREEN);
tft.drawLine(218, 166, 138, 210, GREEN);
Serial.println("Drew Line 1");

tft.fillCircle(138, 210, 4, BLUE);
tft.drawLine(138, 210, 108, 126, BLUE);
Serial.println("Drew Line 2");

tft.fillCircle(108, 126, 4, MAGENTA);
tft.drawLine(108, 126, 28, 169, MAGENTA);
Serial.println("Drew Line 3");

tft.fillCircle(28, 169, 3, YELLOW);
tft.drawLine(28, 169, 26, 78, YELLOW);
tft.fillCircle(26, 78, 2, YELLOW);
Serial.println("Drew Line 4");

delay(5000);

tft.fillScreen(BLACK);
Serial.println("Made screen black");

//Camelopardalis

tft.fillCircle(37, 289, 2, GREEN);
tft.drawLine(37, 289, 52, 240, GREEN);
Serial.println("Drew Line 1");

tft.fillCircle(52, 240, 1, BLUE);
tft.drawLine(52, 240, 74, 140, BLUE);
tft.fillCircle(74, 140, 2, BLUE);
Serial.println("Drew Line 2");

tft.fillCircle(139, 182, 1, MAGENTA);
tft.drawLine(139, 182, 74, 140, MAGENTA);
Serial.println("Drew Line 3");

tft.fillCircle(139, 182, 2, YELLOW);
tft.drawLine(139, 182, 190, 60, YELLOW);
Serial.println("Drew Line 4");

tft.fillCircle(139, 182, 2, CYAN);
tft.drawLine(139, 182, 37, 289, CYAN);
Serial.println("Drew Line 5");

delay(5000);

tft.fillScreen(BLACK);
Serial.println("Made screen black");

//Lynx
tft.fillCircle(200, 20 + shift*4, 3, GREEN);
tft.drawLine(200, 20 + shift*4, 215, 60 + shift*4, GREEN);
Serial.println("Drew Line 1");

tft.fillCircle(215, 60 + shift*4, 2, BLUE);
tft.drawLine(215, 60 + shift*4, 205, 95 + shift*4, BLUE);
Serial.println("Drew Line 2");

tft.fillCircle(205, 95 + shift*4, 2, MAGENTA);
tft.drawLine(205, 95 + shift*4, 220, 115 + shift*4, MAGENTA);
Serial.println("Drew Line 3");

tft.fillCircle(220, 115 + shift*4, 2, YELLOW);
tft.drawLine(220, 115 + shift*4, 190, 150 + shift*4, YELLOW);
Serial.println("Drew Line 4");

tft.fillCircle(190, 150 + shift*4, 2, RED);
tft.drawLine(190, 150 + shift*4, 180, 200 + shift*4, RED);
Serial.println("Drew Line 5");

tft.fillCircle(180, 200 + shift*4, 1, ORANGE);
tft.drawLine(180, 200 + shift*4, 197, 240 + shift*4, ORANGE);
Serial.println("Drew Line 6");

tft.fillCircle(197, 240 + shift*4, 2, CYAN);
tft.drawLine(197, 240 + shift*4, 185, 270 + shift*4, CYAN);
tft.fillCircle(185, 270 + shift*4, 1, CYAN);
Serial.println("Drew Line 7");

delay(5000);

//tft.fillScreen(BLACK);
//Serial.println("Made screen black");


//Ursa Major (Big Dipper)

tft.fillCircle(200, 17, 5, GREEN);
tft.drawLine(200, 17, 170, 45, GREEN);
Serial.println("Drew Line 1");

tft.fillCircle(170, 45, 4, BLUE);
tft.drawLine(170, 45, 130, 50, BLUE);
Serial.println("Drew Line 2");

tft.fillCircle(130, 50, 5, MAGENTA);
tft.drawLine(130, 50, 90, 60, MAGENTA);
Serial.println("Drew Line 3");

tft.fillCircle(90, 60, 2, YELLOW);
tft.drawLine(90, 60, 57, 117, YELLOW);
Serial.println("Drew Line 4");

tft.fillCircle(57, 117, 3, RED);
tft.drawLine(57, 117, 30, 82, RED);
Serial.println("Drew Line 5");

tft.fillCircle(30, 82, 3, ORANGE);
tft.drawLine(30, 82, 55, 45, ORANGE);
Serial.println("Drew Line 5");

tft.fillCircle(55, 45, 3, CYAN);
tft.drawLine(55, 45, 90, 60, CYAN);
Serial.println("Drew Line 5");


delay(10000);

tft.fillScreen(BLACK);
Serial.println("Made screen black");

}// end loop


unsigned long testFillScreen() {
  unsigned long start = micros();
  tft.fillScreen(BLACK);
  tft.fillScreen(RED);
  tft.fillScreen(GREEN);
  tft.fillScreen(BLUE);
  tft.fillScreen(BLACK);
  return micros() - start;
}

unsigned long testText() {
  tft.fillScreen(BLACK);
  unsigned long start = micros();
  tft.setCursor(0, 0);
  tft.setTextColor(WHITE);  tft.setTextSize(1);
  tft.println("Hello World!");
  tft.setTextColor(YELLOW); tft.setTextSize(2);
  tft.println(1234.56);
  tft.setTextColor(RED);    tft.setTextSize(3);
  tft.println(0xDEADBEEF, HEX);
  tft.println();
  tft.setTextColor(GREEN);
  tft.setTextSize(5);
  tft.println("Groop");
  tft.setTextSize(2);
  tft.println("I implore thee,");
  tft.setTextSize(1);
  tft.println("my foonting turlingdromes.");
  tft.println("And hooptiously drangle me");
  tft.println("with crinkly bindlewurdles,");
  tft.println("Or I will rend thee");
  tft.println("in the gobberwarts");
  tft.println("with my blurglecruncheon,");
  tft.println("see if I don't!");
  return micros() - start;
}

unsigned long testLines(uint16_t color) {
  unsigned long start, t;
  int           x1, y1, x2, y2,
                w = tft.width(),
                h = tft.height();

  tft.fillScreen(BLACK);

  x1 = y1 = 0;
  y2    = h - 1;
  start = micros();
//  for(x2=0; x2<w; x2+=6) tft.drawLine(x1, y1, x2, y2, color);
//  x2    = w - 1;
//  for(y2=0; y2<h; y2+=6) tft.drawLine(x1, y1, x2, y2, color);
//tft.drawLine(190, 508, 310, 557, WHITE);

  t     = micros() - start; // fillScreen doesn't count against timing

  tft.fillScreen(BLACK);

  x1    = w - 1;
  y1    = 0;
  y2    = h - 1;
  start = micros();
  for(x2=0; x2<w; x2+=6) tft.drawLine(x1, y1, x2, y2, color);
  x2    = 0;
  for(y2=0; y2<h; y2+=6) tft.drawLine(x1, y1, x2, y2, color);
  t    += micros() - start;

  tft.fillScreen(BLACK);

  x1    = 0;
  y1    = h - 1;
  y2    = 0;
  start = micros();
  for(x2=0; x2<w; x2+=6) tft.drawLine(x1, y1, x2, y2, color);
  x2    = w - 1;
  for(y2=0; y2<h; y2+=6) tft.drawLine(x1, y1, x2, y2, color);
  t    += micros() - start;

  tft.fillScreen(BLACK);

  x1    = w - 1;
  y1    = h - 1;
  y2    = 0;
  start = micros();
  for(x2=0; x2<w; x2+=6) tft.drawLine(x1, y1, x2, y2, color);
  x2    = 0;
  for(y2=0; y2<h; y2+=6) tft.drawLine(x1, y1, x2, y2, color);



  return micros() - start;
}

unsigned long testFastLines(uint16_t color1, uint16_t color2) {
  unsigned long start;
  int           x, y, w = tft.width(), h = tft.height();

  tft.fillScreen(BLACK);
  start = micros();
  for(y=0; y<h; y+=5) tft.drawFastHLine(0, y, w, color1);
  for(x=0; x<w; x+=5) tft.drawFastVLine(x, 0, h, color2);

  return micros() - start;
}

unsigned long testRects(uint16_t color) {
  unsigned long start;
  int           n, i, i2,
                cx = tft.width()  / 2,
                cy = tft.height() / 2;

  tft.fillScreen(BLACK);
  n     = min(tft.width(), tft.height());
  start = micros();
  for(i=2; i<n; i+=6) {
    i2 = i / 2;
    tft.drawRect(cx-i2, cy-i2, i, i, color);
  }

  return micros() - start;
}

unsigned long testFilledRects(uint16_t color1, uint16_t color2) {
  unsigned long start, t = 0;
  int           n, i, i2,
                cx = tft.width()  / 2 - 1,
                cy = tft.height() / 2 - 1;

  tft.fillScreen(BLACK);
  n = min(tft.width(), tft.height());
  for(i=n; i>0; i-=6) {
    i2    = i / 2;
    start = micros();
    tft.fillRect(cx-i2, cy-i2, i, i, color1);
    t    += micros() - start;
    // Outlines are not included in timing results
    tft.drawRect(cx-i2, cy-i2, i, i, color2);
  }

  return t;
}

unsigned long testFilledCircles(uint8_t radius, uint16_t color) {
  unsigned long start;
  int x, y, w = tft.width(), h = tft.height(), r2 = radius * 2;

  tft.fillScreen(BLACK);
  start = micros();
  for(x=radius; x<w; x+=r2) {
    for(y=radius; y<h; y+=r2) {
      tft.fillCircle(x, y, radius, color);
    }
  }

  return micros() - start;
}

unsigned long testCircles(uint8_t radius, uint16_t color) {
  unsigned long start;
  int           x, y, r2 = radius * 2,
                w = tft.width()  + radius,
                h = tft.height() + radius;

  // Screen is not cleared for this one -- this is
  // intentional and does not affect the reported time.
  start = micros();
  for(x=0; x<w; x+=r2) {
    for(y=0; y<h; y+=r2) {
      tft.drawCircle(x, y, radius, color);
    }
  }

  return micros() - start;
}

unsigned long testTriangles() {
  unsigned long start;
  int           n, i, cx = tft.width()  / 2 - 1,
                      cy = tft.height() / 2 - 1;

  tft.fillScreen(BLACK);
  n     = min(cx, cy);
  start = micros();
  for(i=0; i<n; i+=5) {
    tft.drawTriangle(
      cx    , cy - i, // peak
      cx - i, cy + i, // bottom left
      cx + i, cy + i, // bottom right
      tft.color565(0, 0, i));
  }

  return micros() - start;
}

unsigned long testFilledTriangles() {
  unsigned long start, t = 0;
  int           i, cx = tft.width()  / 2 - 1,
                   cy = tft.height() / 2 - 1;

  tft.fillScreen(BLACK);
  start = micros();
  for(i=min(cx,cy); i>10; i-=5) {
    start = micros();
    tft.fillTriangle(cx, cy - i, cx - i, cy + i, cx + i, cy + i,
      tft.color565(0, i, i));
    t += micros() - start;
    tft.drawTriangle(cx, cy - i, cx - i, cy + i, cx + i, cy + i,
      tft.color565(i, i, 0));
  }

  return t;
}

unsigned long testRoundRects() {
  unsigned long start;
  int           w, i, i2,
                cx = tft.width()  / 2 - 1,
                cy = tft.height() / 2 - 1;

  tft.fillScreen(BLACK);
  w     = min(tft.width(), tft.height());
  start = micros();
  for(i=0; i<w; i+=6) {
    i2 = i / 2;
    tft.drawRoundRect(cx-i2, cy-i2, i, i, i/8, tft.color565(i, 0, 0));
  }

  return micros() - start;
}

unsigned long testFilledRoundRects() {
  unsigned long start;
  int           i, i2,
                cx = tft.width()  / 2 - 1,
                cy = tft.height() / 2 - 1;

  tft.fillScreen(BLACK);
  start = micros();
  for(i=min(tft.width(), tft.height()); i>20; i-=6) {
    i2 = i / 2;
    tft.fillRoundRect(cx-i2, cy-i2, i, i, i/8, tft.color565(0, i, 0));
  }

  return micros() - start;
}
